@@ -35,12 +35,18 @@
 #include "AbstractProxyResponseCommand.h"
 #include "HttpConnection.h"
 #include "Request.h"
+#include "Segment.h"
 #include "RequestGroup.h"
 #include "DownloadEngine.h"
+#include "HttpRequest.h"
 #include "HttpResponse.h"
 #include "HttpRequestCommand.h"
+#include "Socket.h"
 #include "DlRetryEx.h"
 #include "message.h"
+#include "HttpHeader.h"
+
+namespace aria2 {
 
 AbstractProxyResponseCommand::AbstractProxyResponseCommand(int cuid,
 							   const RequestHandle& req,
@@ -60,9 +66,11 @@ bool AbstractProxyResponseCommand::executeInternal() {
     e->commands.push_back(this);
     return false;
   }
-  if(httpResponse->getStatus() != 200) {
-    throw new DlRetryEx(EX_PROXY_CONNECTION_FAILED);
+  if(httpResponse->getResponseStatus() != HttpHeader::S200) {
+    throw DL_RETRY_EX(EX_PROXY_CONNECTION_FAILED);
   }
   e->commands.push_back(getNextCommand());
   return true;
 }
+
+} // namespace aria2
