@@ -36,43 +36,60 @@
 #define _D_ACTIVE_PEER_CONNECTION_COMMAND_H_
 
 #include "Command.h"
-#include "BtContextAwareCommand.h"
-#include "DownloadEngine.h"
+#include "SharedHandle.h"
 #include "TimeA2.h"
-#include "RequestGroupAware.h"
 
-class ActivePeerConnectionCommand : public Command,
-				    public BtContextAwareCommand,
-				    public RequestGroupAware
-{
+namespace aria2 {
+
+class RequestGroup;
+class DownloadEngine;
+class Peer;
+class BtContext;
+class BtRuntime;
+class PieceStorage;
+class PeerStorage;
+class BtAnnounce;
+
+class ActivePeerConnectionCommand : public Command {
 private:
-  int32_t interval; // UNIT: sec
+  RequestGroup* _requestGroup;
+  SharedHandle<BtContext> _btContext;
+  SharedHandle<BtRuntime> _btRuntime;
+  SharedHandle<PieceStorage> _pieceStorage;
+  SharedHandle<PeerStorage> _peerStorage;
+  SharedHandle<BtAnnounce> _btAnnounce;
+
+  time_t interval; // UNIT: sec
   DownloadEngine* e;
   Time checkPoint;
-  int32_t _lowestSpeedLimit; // UNIT: byte/sec
-  int32_t _numNewConnection; // the number of the connection to establish.
+  unsigned int _numNewConnection; // the number of the connection to establish.
 public:
   ActivePeerConnectionCommand(int cuid,
 			      RequestGroup* requestGroup,
 			      DownloadEngine* e,
-			      const BtContextHandle& btContext,
-			      int32_t interval);
-     
-  virtual ~ActivePeerConnectionCommand();
+			      const SharedHandle<BtContext>& btContext,
+			      time_t interval);
 
+  virtual ~ActivePeerConnectionCommand();
+     
   virtual bool execute();
 
-  void connectToPeer(const PeerHandle& peer);
+  void connectToPeer(const SharedHandle<Peer>& peer);
 
-  void setLowestSpeedLimit(int32_t speed)
-  {
-    _lowestSpeedLimit = speed;
-  }
-
-  void setNumNewConnection(int32_t numNewConnection)
+  void setNumNewConnection(size_t numNewConnection)
   {
     _numNewConnection = numNewConnection;
   }
+
+  void setBtRuntime(const SharedHandle<BtRuntime>& btRuntime);
+
+  void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage);
+
+  void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage);
+
+  void setBtAnnounce(const SharedHandle<BtAnnounce>& btAnnounce);
 };
 
+} // namespace aria2
+
 #endif // _D_ACTIVE_PEER_CONNECTION_COMMAND_H_
