@@ -33,12 +33,24 @@
  */
 /* copyright --> */
 #include "AnnounceList.h"
-#include "List.h"
-#include "Data.h"
 
-AnnounceList::AnnounceList(const MetaEntry* announceListEntry):
+#include <algorithm>
+
+#include "A2STR.h"
+#include "SimpleRandomizer.h"
+#include "bencode.h"
+
+namespace aria2 {
+
+const std::string AnnounceList::STARTED("started");
+
+const std::string AnnounceList::STOPPED("stopped");
+
+const std::string AnnounceList::COMPLETED("completed");
+
+AnnounceList::AnnounceList(const BDE& announceList):
   currentTrackerInitialized(false) {
-  reconfigure(announceListEntry);
+  reconfigure(announceList);
 }
 
 AnnounceList::AnnounceList(const AnnounceTiers& announceTiers):
@@ -46,19 +58,24 @@ AnnounceList::AnnounceList(const AnnounceTiers& announceTiers):
   resetIterator();
 }
 
-void AnnounceList::reconfigure(const MetaEntry* announceListEntry) {
-  const List* l = dynamic_cast<const List*>(announceListEntry);
-  if(l) {
-    for(MetaList::const_iterator itr = l->getList().begin();
-	itr != l->getList().end(); itr++) {
-      const List* elem = (List*)*itr;
-      Strings urls;
-      for(MetaList::const_iterator elemItr = elem->getList().begin();
-	  elemItr != elem->getList().end(); elemItr++) {
-	const Data* data = (Data*)*elemItr;
-	urls.push_back(data->toString());
+void AnnounceList::reconfigure(const BDE& announceList)
+{
+  if(announceList.isList()) {
+    for(BDE::List::const_iterator itr = announceList.listBegin();
+	itr != announceList.listEnd(); ++itr) {
+      const BDE& elemList = *itr;
+      if(!elemList.isList()) {
+	continue;
       }
-      if(urls.size()) {
+      std::deque<std::string> urls;
+      for(BDE::List::const_iterator elemItr = elemList.listBegin();
+	  elemItr != elemList.listEnd(); ++elemItr) {
+	const BDE& data = *elemItr;
+	if(data.isString()) {
+	  urls.push_back(data.s());
+	}
+      }
+      if(!urls.empty()) {
 	AnnounceTierHandle tier(new AnnounceTier(urls));
 	tiers.push_back(tier);
       }
@@ -67,8 +84,8 @@ void AnnounceList::reconfigure(const MetaEntry* announceListEntry) {
   }
 }
 
-void AnnounceList::reconfigure(const string& url) {
-  Strings urls;
+void AnnounceList::reconfigure(const std::string& url) {
+  std::deque<std::string> urls;
   urls.push_back(url);
   tiers.push_back(AnnounceTierHandle(new AnnounceTier(urls)));
   resetIterator();
@@ -84,18 +101,18 @@ void AnnounceList::resetIterator() {
   }
 }
 
-string AnnounceList::getAnnounce() const {
+std::string AnnounceList::getAnnounce() const {
   if(currentTrackerInitialized) {
     return *currentTracker;
   } else {
-    return "";
+    return A2STR::NIL;
   }
 }
 
 void AnnounceList::announceSuccess() {
   if(currentTrackerInitialized) {
     (*currentTier)->nextEvent();
-    string url = *currentTracker;
+    std::string url = *currentTracker;
     (*currentTier)->urls.erase(currentTracker);
     (*currentTier)->urls.push_front(url);
     currentTier = tiers.begin();
@@ -105,11 +122,11 @@ void AnnounceList::announceSuccess() {
 
 void AnnounceList::announceFailure() {
   if(currentTrackerInitialized) {
-    currentTracker++;
+    ++currentTracker;
     if(currentTracker == (*currentTier)->urls.end()) {
       // force next event
       (*currentTier)->nextEventIfAfterStarted();
-      currentTier++;
+      ++currentTier;
       if(currentTier == tiers.end()) {
 	currentTrackerInitialized = false;
       } else {
@@ -133,21 +150,21 @@ void AnnounceList::setEvent(AnnounceTier::AnnounceEvent event) {
   }
 }
 
-string AnnounceList::getEventString() const {
+std::string AnnounceList::getEventString() const {
   if(currentTrackerInitialized) {
     switch((*currentTier)->event) {
     case AnnounceTier::STARTED:
     case AnnounceTier::STARTED_AFTER_COMPLETION:
-      return "started";
+      return STARTED;
     case AnnounceTier::STOPPED:
-      return "stopped";
+      return STOPPED;
     case AnnounceTier::COMPLETED:
-      return "completed";
+      return COMPLETED;
     default:
-      return "";
+      return A2STR::NIL;
     }
   } else {
-    return "";
+    return A2STR::NIL;
   }
 }
 
@@ -179,11 +196,11 @@ public:
   }
 };
 
-int32_t AnnounceList::countStoppedAllowedTier() const {
+size_t AnnounceList::countStoppedAllowedTier() const {
   return count_if(tiers.begin(), tiers.end(), FindStoppedAllowedTier());
 }
 
-int32_t AnnounceList::countCompletedAllowedTier() const {
+size_t AnnounceList::countCompletedAllowedTier() const {
   return count_if(tiers.begin(), tiers.end(), FindCompletedAllowedTier());
 }
 
@@ -198,10 +215,9 @@ template<class InputIterator, class Predicate>
 InputIterator
 find_wrap_if(InputIterator first, InputIterator last,
 	     InputIterator current, Predicate pred) {
-  InputIterator itr = find_if(current, last,
-			      pred);
+  InputIterator itr = std::find_if(current, last, pred);
   if(itr == last) {
-    itr = find_if(first, current, pred);
+    itr = std::find_if(first, current, pred);
   }
   return itr;
 }
@@ -222,9 +238,10 @@ void AnnounceList::moveToCompletedAllowedTier() {
 
 void AnnounceList::shuffle() {
   for(AnnounceTiers::iterator itr = tiers.begin();
-      itr != tiers.end(); itr++) {
-    Strings& urls = (*itr)->urls;
-    random_shuffle(urls.begin(), urls.end());
+      itr != tiers.end(); ++itr) {
+    std::deque<std::string>& urls = (*itr)->urls;
+    std::random_shuffle(urls.begin(), urls.end(),
+			*(SimpleRandomizer::getInstance().get()));
   }
 }
 
@@ -255,3 +272,5 @@ bool AnnounceList::currentTierAcceptsCompletedEvent() const
     return false;
   }
 }
+
+} // namespace aria2
