@@ -36,6 +36,7 @@
 #include "RequestGroup.h"
 #include "Option.h"
 #include "LogFactory.h"
+#include "Logger.h"
 #include "DefaultBtContext.h"
 #include "RecoverableException.h"
 #include "message.h"
@@ -43,13 +44,14 @@
 #include "Util.h"
 #include "PieceStorage.h"
 #include "DiskAdaptor.h"
+#include "File.h"
+
+namespace aria2 {
 
 BtDependency::BtDependency(const RequestGroupWeakHandle& dependant,
-			   const RequestGroupHandle& dependee,
-			   const Option* option):
+			   const RequestGroupHandle& dependee):
   _dependant(dependant),
   _dependee(dependee),
-  _option(option),
   _logger(LogFactory::getInstance()) {}
 
 BtDependency::~BtDependency() {}
@@ -59,21 +61,33 @@ bool BtDependency::resolve()
   if(_dependee->getNumCommand() == 0 && _dependee->downloadFinished()) {
     RequestGroupHandle dependee = _dependee;
     // cut reference here
-    _dependee = 0;
-    DefaultBtContextHandle btContext = new DefaultBtContext();
+    _dependee.reset();
+    DefaultBtContextHandle btContext(new DefaultBtContext());
+    btContext->setDir(_dependant->getDownloadContext()->getDir());
     try {
       DiskAdaptorHandle diskAdaptor = dependee->getPieceStorage()->getDiskAdaptor();
       diskAdaptor->openExistingFile();
-      string content = Util::toString(diskAdaptor);
-      btContext->loadFromMemory(content.c_str(), content.size(),
-				File(dependee->getFilePath()).getBasename());
-      if(_option->defined(PREF_PEER_ID_PREFIX)) {
-	btContext->setPeerIdPrefix(_option->get(PREF_PEER_ID_PREFIX));
+      std::string content = Util::toString(diskAdaptor);
+
+      std::string overrideName;
+      if(Util::startsWith(_dependant->getDownloadContext()->getActualBasePath(),
+			  _dependant->getDownloadContext()->getDir())) {
+	overrideName =
+	  _dependant->getDownloadContext()->getActualBasePath().substr
+	  (_dependant->getDownloadContext()->getDir().size());
+	if(Util::startsWith(overrideName, "/")) {
+	  overrideName = overrideName.substr(1);
+	}
       }
-      btContext->setDir(_dependant->getDownloadContext()->getDir());
-    } catch(RecoverableException* e) {
+      btContext->loadFromMemory(content,
+				File(dependee->getFilePath()).getBasename(),
+				overrideName);
+      if(_dependant->getOption()->defined(PREF_PEER_ID_PREFIX)) {
+	btContext->setPeerIdPrefix
+	  (_dependant->getOption()->get(PREF_PEER_ID_PREFIX));
+      }
+    } catch(RecoverableException& e) {
       _logger->error(EX_EXCEPTION_CAUGHT, e);
-      delete e;
       _logger->debug("BtDependency for GID#%d failed. Go without Bt.",
 		     _dependant->getGID());
       return true;
@@ -85,7 +99,7 @@ bool BtDependency::resolve()
   } else if(_dependee->getNumCommand() == 0) {
     // _dependee's download failed.
     // cut reference here
-    _dependee = 0;
+    _dependee.reset();
     _logger->debug("BtDependency for GID#%d failed. Go without Bt.",
 		   _dependant->getGID());    
     return true;
@@ -93,3 +107,5 @@ bool BtDependency::resolve()
     return false;
   }
 }
+
+} // namespace aria2
