@@ -33,12 +33,15 @@
  */
 /* copyright --> */
 #include "BtPieceMessage.h"
+
+#include <cstring>
+#include <cstdlib>
+#include <cassert>
+
 #include "PeerMessageUtil.h"
 #include "Util.h"
 #include "message.h"
 #include "DlAbortEx.h"
-#include "BtChokingEvent.h"
-#include "BtCancelSendingPieceEvent.h"
 #include "MessageDigestHelper.h"
 #include "DiskAdaptor.h"
 #include "Logger.h"
@@ -51,12 +54,11 @@
 #include "BtRequestFactory.h"
 #include "PeerConnection.h"
 #include "StringFormat.h"
-#include <cstring>
-#include <cstdlib>
-#include <cassert>
 
 namespace aria2 {
 
+const std::string BtPieceMessage::NAME("piece");
+
 void BtPieceMessage::setBlock(const unsigned char* block, size_t blockLength) {
   delete [] this->block;
   this->blockLength = blockLength;
@@ -65,15 +67,8 @@ void BtPieceMessage::setBlock(const unsigned char* block, size_t blockLength) {
 }
 
 BtPieceMessageHandle BtPieceMessage::create(const unsigned char* data, size_t dataLength) {
-  if(dataLength <= 9) {
-    throw DlAbortEx
-      (StringFormat(EX_INVALID_PAYLOAD_SIZE, "piece", dataLength, 9).str());
-  }
-  uint8_t id = PeerMessageUtil::getId(data);
-  if(id != ID) {
-    throw DlAbortEx
-      (StringFormat(EX_INVALID_BT_MESSAGE_ID, id, "piece", ID).str());
-  }
+  PeerMessageUtil::assertPayloadLengthGreater(9, dataLength, NAME);
+  PeerMessageUtil::assertID(ID, data, NAME);
   BtPieceMessageHandle message(new BtPieceMessage());
   message->setIndex(PeerMessageUtil::getIntParam(data, 1));
   message->setBegin(PeerMessageUtil::getIntParam(data, 5));
@@ -168,13 +163,13 @@ size_t BtPieceMessage::sendPieceData(off_t offset, size_t length) const {
      static_cast<ssize_t>(length)) {
     return peerConnection->sendMessage(buf, length);
   } else {
-    throw DlAbortEx(EX_DATA_READ);
+    throw DL_ABORT_EX(EX_DATA_READ);
   }
 }
 
 std::string BtPieceMessage::toString() const {
-  return "piece index="+Util::itos(index)+", begin="+Util::itos(begin)+
-    ", length="+Util::itos(blockLength);
+  return strconcat(NAME, " index=", Util::itos(index), ", begin=",
+		   Util::itos(begin), ", length=", Util::itos(blockLength));
 }
 
 bool BtPieceMessage::checkPieceHash(const PieceHandle& piece) {
@@ -210,7 +205,7 @@ void BtPieceMessage::erasePieceOnDisk(const PieceHandle& piece) {
   memset(buf, 0, BUFSIZE);
   off_t offset = (off_t)piece->getIndex()*btContext->getPieceLength();
   div_t res = div(piece->getLength(), BUFSIZE);
-  for(int i = 0; i < res.quot; i++) {
+  for(int i = 0; i < res.quot; ++i) {
     pieceStorage->getDiskAdaptor()->writeData(buf, BUFSIZE, offset);
     offset += BUFSIZE;
   }
@@ -219,16 +214,8 @@ void BtPieceMessage::erasePieceOnDisk(const PieceHandle& piece) {
   }
 }
 
-bool BtPieceMessage::BtChokingEventListener::canHandle(const BtEventHandle& event) {
-  BtChokingEvent* intEvent = dynamic_cast<BtChokingEvent*>(event.get());
-  return intEvent != 0;
-}
-
-void BtPieceMessage::BtChokingEventListener::handleEventInternal(const BtEventHandle& event) {
-  message->handleChokingEvent(event);
-}
-
-void BtPieceMessage::handleChokingEvent(const BtEventHandle& event) {
+void BtPieceMessage::onChokingEvent(const BtChokingEvent& event)
+{
   if(!invalidate &&
      !sendingInProgress &&
      !peer->isInAmAllowedIndexSet(index)) {
@@ -248,22 +235,14 @@ void BtPieceMessage::handleChokingEvent(const BtEventHandle& event) {
   }
 }
 
-bool BtPieceMessage::BtCancelSendingPieceEventListener::canHandle(const BtEventHandle& event) {
-  BtCancelSendingPieceEvent* intEvent = dynamic_cast<BtCancelSendingPieceEvent*>(event.get());
-  return intEvent != 0;
-}
-
-void BtPieceMessage::BtCancelSendingPieceEventListener::handleEventInternal(const BtEventHandle& event) {
-  message->handleCancelSendingPieceEvent(event);
-}
-
-void BtPieceMessage::handleCancelSendingPieceEvent(const BtEventHandle& event) {
-  BtCancelSendingPieceEvent* intEvent = (BtCancelSendingPieceEvent*)(event.get());
+void BtPieceMessage::onCancelSendingPieceEvent
+(const BtCancelSendingPieceEvent& event)
+{
   if(!invalidate &&
      !sendingInProgress &&
-     index == intEvent->getIndex() &&
-     begin == intEvent->getBegin() &&
-     blockLength == intEvent->getLength()) {
+     index == event.getIndex() &&
+     begin == event.getBegin() &&
+     blockLength == event.getLength()) {
     logger->debug(MSG_REJECT_PIECE_CANCEL,
 		  cuid, index, begin, blockLength);
     if(peer->isFastExtensionEnabled()) {
