@@ -33,27 +33,23 @@
  */
 /* copyright --> */
 #include "CheckIntegrityCommand.h"
-#include "CheckIntegrityMan.h"
 #include "CheckIntegrityEntry.h"
+#include "DownloadEngine.h"
 #include "RequestGroup.h"
-#include "FileAllocationEntry.h"
-#include "InitiateConnectionCommandFactory.h"
-#include "DlAbortEx.h"
+#include "Logger.h"
 #include "message.h"
-#include "DownloadCommand.h"
 #include "prefs.h"
 
-CheckIntegrityCommand::CheckIntegrityCommand(int32_t cuid, RequestGroup* requestGroup, DownloadEngine* e, const CheckIntegrityEntryHandle& entry):
+namespace aria2 {
+
+CheckIntegrityCommand::CheckIntegrityCommand
+(int32_t cuid, RequestGroup* requestGroup, DownloadEngine* e,
+ const CheckIntegrityEntryHandle& entry):
   RealtimeCommand(cuid, requestGroup, e),
   _entry(entry)
-{
-  _e->_checkIntegrityMan->addCheckIntegrityEntry(_entry);
-}
+{}
 
-CheckIntegrityCommand::~CheckIntegrityCommand()
-{
-  _e->_checkIntegrityMan->removeCheckIntegrityEntry(_entry);
-}
+CheckIntegrityCommand::~CheckIntegrityCommand() {}
 
 bool CheckIntegrityCommand::executeInternal()
 {
@@ -62,15 +58,22 @@ bool CheckIntegrityCommand::executeInternal()
   }
   _entry->validateChunk();
   if(_entry->finished()) {
+    _e->_checkIntegrityMan->dropPickedEntry();
+
     if(_requestGroup->downloadFinished()) {
       logger->notice(MSG_VERIFICATION_SUCCESSFUL,
 		     _requestGroup->getFilePath().c_str());
-      _e->addCommand(_entry->onDownloadFinished(_e));
+      std::deque<Command*> commands;
+      _entry->onDownloadFinished(commands, _e);
+      _e->addCommand(commands);
     } else {
       logger->error(MSG_VERIFICATION_FAILED,
 		    _requestGroup->getFilePath().c_str());
-      _e->addCommand(_entry->onDownloadIncomplete(_e));
+      std::deque<Command*> commands;
+      _entry->onDownloadIncomplete(commands,_e);
+      _e->addCommand(commands);
     }
+    _e->setNoWait(true);
     return true;
   } else {
     _e->commands.push_back(this);
@@ -78,9 +81,13 @@ bool CheckIntegrityCommand::executeInternal()
   }
 }
 
-bool CheckIntegrityCommand::handleException(Exception* e)
+bool CheckIntegrityCommand::handleException(Exception& e)
 {
+  _e->_checkIntegrityMan->dropPickedEntry();
   logger->error(MSG_FILE_VALIDATION_FAILURE, e, cuid);
-  logger->error(MSG_DOWNLOAD_NOT_COMPLETE, cuid, _requestGroup->getFilePath().c_str());
+  logger->error(MSG_DOWNLOAD_NOT_COMPLETE,
+		cuid, _requestGroup->getFilePath().c_str());
   return true;
 }
+
+} // namespace aria2
