@@ -36,28 +36,14 @@
 #define _D_CHECK_INTEGRITY_MAN_H_
 
 #include "common.h"
+#include "SequentialPicker.h"
+
+namespace aria2 {
 
 class CheckIntegrityEntry;
-typedef SharedHandle<CheckIntegrityEntry> CheckIntegrityEntryHandle;
-typedef deque<CheckIntegrityEntryHandle> CheckIntegrityEntries;
 
-class CheckIntegrityMan {
-private:
-  CheckIntegrityEntries _checkIntegrityEntries;
-public:
-  CheckIntegrityMan();
+typedef SequentialPicker<CheckIntegrityEntry> CheckIntegrityMan;
 
-  ~CheckIntegrityMan();
-
-  void addCheckIntegrityEntry(const CheckIntegrityEntryHandle& entry);
-
-  bool removeCheckIntegrityEntry(const CheckIntegrityEntryHandle& entry);
-
-  CheckIntegrityEntryHandle getFirstCheckIntegrityEntry() const;
-
-  int32_t countCheckIntegrityEntry() const;
-};
-
-typedef SharedHandle<CheckIntegrityMan> CheckIntegrityManHandle;
+} // namespace aria2
 
 #endif // _D_CHECK_INTEGRITY_MAN_H_
