@@ -35,7 +35,7 @@
 #include "DefaultBtAnnounce.h"
 #include "LogFactory.h"
 #include "Logger.h"
-#include "DelegatingPeerListProcessor.h"
+#include "PeerListProcessor.h"
 #include "Util.h"
 #include "prefs.h"
 #include "DlAbortEx.h"
@@ -60,6 +60,7 @@ DefaultBtAnnounce::DefaultBtAnnounce(const BtContextHandle& btContext,
   trackers(0),
   interval(DEFAULT_ANNOUNCE_INTERVAL),
   minInterval(DEFAULT_ANNOUNCE_INTERVAL),
+  _userDefinedInterval(0),
   complete(0),
   incomplete(0),
   announceList(btContext->getAnnounceTiers()),
@@ -80,7 +81,9 @@ void DefaultBtAnnounce::generateKey()
 }
 
 bool DefaultBtAnnounce::isDefaultAnnounceReady() {
-  return (trackers == 0 && prevAnnounceTime.elapsed(minInterval) &&
+  return (trackers == 0 &&
+	  prevAnnounceTime.elapsed(_userDefinedInterval==0?
+				   minInterval:_userDefinedInterval) &&
 	  !announceList.allTiersFailed());
 }
 
@@ -141,23 +144,31 @@ std::string DefaultBtAnnounce::getAnnounceUrl() {
     pieceStorage->getTotalLength()-pieceStorage->getCompletedLength();
   std::string url = announceList.getAnnounce();
   url += uriHasQuery(url) ? "&" : "?";
-  url += 
-    "info_hash="+Util::torrentUrlencode(btContext->getInfoHash(),
-					btContext->getInfoHashLength())+
-    "&peer_id="+Util::torrentUrlencode(btContext->getPeerId(), 20)+
-    "&uploaded="+Util::uitos(stat.getSessionUploadLength())+
-    "&downloaded="+Util::uitos(stat.getSessionDownloadLength())+
-    "&left="+Util::uitos(left)+
-    "&compact=1"+
-    "&key="+key+
-    "&numwant="+Util::uitos(numWant)+
-    "&no_peer_id=1";
+  url += "info_hash=";
+  url += Util::torrentUrlencode(btContext->getInfoHash(),
+				btContext->getInfoHashLength());
+  url += "&peer_id=";
+  url += Util::torrentUrlencode(btContext->getPeerId(), 20);
+  url += "&uploaded=";
+  url += Util::uitos(stat.getSessionUploadLength());
+  url += "&downloaded=";
+  url += Util::uitos(stat.getSessionDownloadLength());
+  url += "&left=";
+  url += Util::uitos(left);
+  url += "&compact=1";
+  url += "&key=";
+  url += key;
+  url += "&numwant=";
+  url += Util::uitos(numWant);
+  url += "&no_peer_id=1";
   if(btRuntime->getListenPort() > 0) {
-    url += "&port="+Util::uitos(btRuntime->getListenPort());
+    url += "&port=";
+    url += Util::uitos(btRuntime->getListenPort());
   }
   std::string event = announceList.getEventString();
   if(!event.empty()) {
-    url += "&event="+event;
+    url += "&event=";
+    url += event;
   }
   if(!trackerId.empty()) {
     url += "&trackerid="+Util::torrentUrlencode(trackerId);
@@ -167,6 +178,10 @@ std::string DefaultBtAnnounce::getAnnounceUrl() {
   } else {
     url += "&supportcrypto=1";
   }
+  if(!option->blank(PREF_BT_EXTERNAL_IP)) {
+    url += "&ip=";
+    url += option->get(PREF_BT_EXTERNAL_IP);
+  }
   return url;
 }
 
@@ -198,31 +213,31 @@ DefaultBtAnnounce::processAnnounceResponse(const unsigned char* trackerResponse,
 					   size_t trackerResponseLength)
 {
   logger->debug("Now processing tracker response.");
-  const bencode::BDE dict =
+  const BDE dict =
     bencode::decode(trackerResponse, trackerResponseLength);
   if(!dict.isDict()) {
-    throw DlAbortEx(MSG_NULL_TRACKER_RESPONSE);
+    throw DL_ABORT_EX(MSG_NULL_TRACKER_RESPONSE);
   }
-  const bencode::BDE& failure = dict[BtAnnounce::FAILURE_REASON];
+  const BDE& failure = dict[BtAnnounce::FAILURE_REASON];
   if(failure.isString()) {
-    throw DlAbortEx
+    throw DL_ABORT_EX
       (StringFormat(EX_TRACKER_FAILURE, failure.s().c_str()).str());
   }
-  const bencode::BDE& warn = dict[BtAnnounce::WARNING_MESSAGE];
+  const BDE& warn = dict[BtAnnounce::WARNING_MESSAGE];
   if(warn.isString()) {
     logger->warn(MSG_TRACKER_WARNING_MESSAGE, warn.s().c_str());
   }
-  const bencode::BDE& tid = dict[BtAnnounce::TRACKER_ID];
+  const BDE& tid = dict[BtAnnounce::TRACKER_ID];
   if(tid.isString()) {
     trackerId = tid.s();
     logger->debug("Tracker ID:%s", trackerId.c_str());
   }
-  const bencode::BDE& ival = dict[BtAnnounce::INTERVAL];
+  const BDE& ival = dict[BtAnnounce::INTERVAL];
   if(ival.isInteger() && ival.i() > 0) {
     interval = ival.i();
     logger->debug("Interval:%d", interval);
   }
-  const bencode::BDE& mival = dict[BtAnnounce::MIN_INTERVAL];
+  const BDE& mival = dict[BtAnnounce::MIN_INTERVAL];
   if(mival.isInteger() && mival.i() > 0) {
     minInterval = mival.i();
     logger->debug("Min interval:%d", minInterval);
@@ -233,26 +248,25 @@ DefaultBtAnnounce::processAnnounceResponse(const unsigned char* trackerResponse,
     // Use interval as a minInterval if minInterval is not supplied.
     minInterval = interval;
   }
-  const bencode::BDE& comp = dict[BtAnnounce::COMPLETE];
+  const BDE& comp = dict[BtAnnounce::COMPLETE];
   if(comp.isInteger()) {
     complete = comp.i();
     logger->debug("Complete:%d", complete);
   }
-  const bencode::BDE& incomp = dict[BtAnnounce::INCOMPLETE];
+  const BDE& incomp = dict[BtAnnounce::INCOMPLETE];
   if(incomp.isInteger()) {
     incomplete = incomp.i();
     logger->debug("Incomplete:%d", incomplete);
   }
-  const bencode::BDE& peerData = dict[BtAnnounce::PEERS];
-  if(!peerData.isNone()) {
+  const BDE& peerData = dict[BtAnnounce::PEERS];
+  if(peerData.isNone()) {
+    logger->info(MSG_NO_PEER_LIST_RECEIVED);
+  } else {
     if(!btRuntime->isHalt() && btRuntime->lessThanMinPeers()) {
-      DelegatingPeerListProcessor proc;
       std::deque<SharedHandle<Peer> > peers;
-      proc.extractPeer(peers, peerData);
+      PeerListProcessor().extractPeer(peerData, std::back_inserter(peers));
       peerStorage->addPeer(peers);
     }
-  } else {
-    logger->info(MSG_NO_PEER_LIST_RECEIVED);
   }
 }
 
@@ -276,31 +290,16 @@ void DefaultBtAnnounce::setBtRuntime(const BtRuntimeHandle& btRuntime)
   this->btRuntime = btRuntime;
 }
 
-BtRuntimeHandle DefaultBtAnnounce::getBtRuntime() const
-{
-  return btRuntime;
-}
-
 void DefaultBtAnnounce::setPieceStorage(const PieceStorageHandle& pieceStorage)
 {
   this->pieceStorage = pieceStorage;
 }
 
-PieceStorageHandle DefaultBtAnnounce::getPieceStorage() const
-{
-  return pieceStorage;
-}
-
 void DefaultBtAnnounce::setPeerStorage(const PeerStorageHandle& peerStorage)
 {
   this->peerStorage = peerStorage;
 }
 
-PeerStorageHandle DefaultBtAnnounce::getPeerStorage() const
-{
-  return peerStorage;
-}
-
 void DefaultBtAnnounce::overrideMinInterval(time_t interval)
 {
   minInterval = interval;
