@@ -33,12 +33,39 @@
  */
 /* copyright --> */
 #include "DefaultBtMessageReceiver.h"
+
+#include <cstring>
+
 #include "BtHandshakeMessage.h"
 #include "message.h"
+#include "BtContext.h"
+#include "Peer.h"
+#include "PeerConnection.h"
+#include "BtMessageDispatcher.h"
+#include "BtMessageFactory.h"
+#include "Logger.h"
+#include "LogFactory.h"
 
-BtMessageHandle DefaultBtMessageReceiver::receiveHandshake(bool quickReply) {
+namespace aria2 {
+
+DefaultBtMessageReceiver::DefaultBtMessageReceiver():
+  cuid(0),
+  handshakeSent(false),
+  logger(LogFactory::getInstance())
+{
+  logger->debug("DefaultBtMessageReceiver::instantiated");
+}
+
+DefaultBtMessageReceiver::~DefaultBtMessageReceiver()
+{
+  logger->debug("DefaultBtMessageReceiver::deleted");
+}
+
+SharedHandle<BtHandshakeMessage>
+DefaultBtMessageReceiver::receiveHandshake(bool quickReply)
+{
   unsigned char data[BtHandshakeMessage::MESSAGE_LENGTH];
-  int32_t dataLength = BtHandshakeMessage::MESSAGE_LENGTH;
+  size_t dataLength = BtHandshakeMessage::MESSAGE_LENGTH;
   bool retval = peerConnection->receiveHandshake(data, dataLength);
   // To handle tracker's NAT-checking feature
   if(!handshakeSent && quickReply && dataLength >= 48) {
@@ -49,27 +76,22 @@ BtMessageHandle DefaultBtMessageReceiver::receiveHandshake(bool quickReply) {
     }
   }
   if(!retval) {
-    return 0;
-  }
-  BtHandshakeMessageHandle msg = messageFactory->createHandshakeMessage(data, dataLength);
-  Errors errors;
-  if(msg->validate(errors)) {
-    if(msg->isFastExtensionSupported()) {
-      peer->setFastExtensionEnabled(true);
-      logger->info(MSG_FAST_EXTENSION_ENABLED, cuid);
-    }
-  } else {
-    // TODO throw exception here based on errors
+    return SharedHandle<BtHandshakeMessage>();
   }
+  SharedHandle<BtHandshakeMessage> msg = messageFactory->createHandshakeMessage(data, dataLength);
+  std::deque<std::string> errors;
+  msg->validate(errors);
   return msg;
 }
 
-BtMessageHandle DefaultBtMessageReceiver::receiveAndSendHandshake() {
+SharedHandle<BtHandshakeMessage>
+DefaultBtMessageReceiver::receiveAndSendHandshake()
+{
   return receiveHandshake(true);
 }
 
 void DefaultBtMessageReceiver::sendHandshake() {
-  BtHandshakeMessageHandle msg =
+  SharedHandle<BtMessage> msg =
     messageFactory->createHandshakeMessage(btContext->getInfoHash(),
 					   btContext->getPeerId());
   dispatcher->addMessageToQueue(msg);
@@ -78,17 +100,43 @@ void DefaultBtMessageReceiver::sendHandshake() {
 
 BtMessageHandle DefaultBtMessageReceiver::receiveMessage() {
   unsigned char data[MAX_PAYLOAD_LEN];
-  int32_t dataLength = 0;
+  size_t dataLength = 0;
   if(!peerConnection->receiveMessage(data, dataLength)) {
-    return 0;
+    return SharedHandle<BtMessage>();
   }
   BtMessageHandle msg = messageFactory->createBtMessage(data, dataLength);
-  Errors errors;
+  std::deque<std::string> errors;
   if(msg->validate(errors)) {
     return msg;
   } else {
     // TODO throw exception here based on errors;
-    return 0;
+    return SharedHandle<BtMessage>();
   }
 }
 
+void DefaultBtMessageReceiver::setBtContext(const SharedHandle<BtContext>& btContext)
+{
+  this->btContext = btContext;
+}
+
+void DefaultBtMessageReceiver::setPeer(const SharedHandle<Peer>& peer)
+{
+  this->peer = peer;
+}
+
+void DefaultBtMessageReceiver::setPeerConnection(const WeakHandle<PeerConnection>& peerConnection)
+{
+  this->peerConnection = peerConnection;
+}
+
+void DefaultBtMessageReceiver::setDispatcher(const WeakHandle<BtMessageDispatcher>& dispatcher)
+{
+  this->dispatcher = dispatcher;
+}
+
+void DefaultBtMessageReceiver::setBtMessageFactory(const WeakHandle<BtMessageFactory>& factory)
+{
+  this->messageFactory = factory;
+}
+
+} // namespace aria2
