@@ -45,7 +45,6 @@
 #include "prefs.h"
 #include "DirectDiskAdaptor.h"
 #include "MultiDiskAdaptor.h"
-#include "CopyDiskAdaptor.h"
 #include "DiskWriter.h"
 #include "BitfieldManFactory.h"
 #include "BitfieldMan.h"
@@ -58,10 +57,13 @@
 #include "Option.h"
 #include "StringFormat.h"
 #include "RarestPieceSelector.h"
+#include "array_fun.h"
+#include "PieceStatMan.h"
 
 namespace aria2 {
 
-DefaultPieceStorage::DefaultPieceStorage(const DownloadContextHandle& downloadContext, const Option* option, bool randomPieceStatsOrdering):
+DefaultPieceStorage::DefaultPieceStorage
+(const DownloadContextHandle& downloadContext, const Option* option):
   downloadContext(downloadContext),
   bitfieldMan(BitfieldManFactory::getFactoryInstance()->
 	      createBitfieldMan(downloadContext->getPieceLength(),
@@ -70,20 +72,14 @@ DefaultPieceStorage::DefaultPieceStorage(const DownloadContextHandle& downloadCo
   endGamePieceNum(END_GAME_PIECE_NUM),
   logger(LogFactory::getInstance()),
   option(option),
-  _pieceSelector(new RarestPieceSelector(downloadContext->getNumPieces(),
-					 randomPieceStatsOrdering))
+  _pieceStatMan(new PieceStatMan(downloadContext->getNumPieces(), true)),
+  _pieceSelector(new RarestPieceSelector(_pieceStatMan))
 {}
 
 DefaultPieceStorage::~DefaultPieceStorage() {
   delete bitfieldMan;
 }
 
-bool DefaultPieceStorage::hasMissingPiece(const PeerHandle& peer)
-{
-  return bitfieldMan->hasMissingPiece(peer->getBitfield(),
-				      peer->getBitfieldLength());
-}
-
 bool DefaultPieceStorage::isEndGame()
 {
   return bitfieldMan->countMissingBlock() <= endGamePieceNum;
@@ -91,18 +87,21 @@ bool DefaultPieceStorage::isEndGame()
 
 bool DefaultPieceStorage::getMissingPieceIndex(size_t& index,
 					       const unsigned char* bitfield,
-					       size_t& length)
+					       size_t length)
 {
-  std::deque<size_t> indexes;
+  const size_t mislen = bitfieldMan->getBitfieldLength();
+  array_ptr<unsigned char> misbitfield(new unsigned char[mislen]);
   bool r;
   if(isEndGame()) {
-    r = bitfieldMan->getAllMissingIndexes(indexes, bitfield, length);
+    r = bitfieldMan->getAllMissingIndexes(misbitfield, mislen,
+					  bitfield, length);
   } else {
-    r = bitfieldMan->getAllMissingUnusedIndexes(indexes, bitfield, length);
+    r = bitfieldMan->getAllMissingUnusedIndexes(misbitfield, mislen,
+						bitfield, length);
   }
   if(r) {
     // We assume indexes is sorted using comparator less.
-    return _pieceSelector->select(index, indexes);
+    return _pieceSelector->select(index, misbitfield,bitfieldMan->countBlock());
   } else {
     return false;
   }
@@ -189,6 +188,14 @@ SharedHandle<Piece> DefaultPieceStorage::getMissingPiece
   return getMissingPiece(bitfield.getBitfield(), bitfield.getBitfieldLength());
 }
 
+#ifdef ENABLE_BITTORRENT
+
+bool DefaultPieceStorage::hasMissingPiece(const PeerHandle& peer)
+{
+  return bitfieldMan->hasMissingPiece(peer->getBitfield(),
+				      peer->getBitfieldLength());
+}
+
 PieceHandle DefaultPieceStorage::getMissingPiece(const SharedHandle<Peer>& peer)
 {
   return getMissingPiece(peer->getBitfield(), peer->getBitfieldLength());
@@ -252,6 +259,8 @@ SharedHandle<Piece> DefaultPieceStorage::getMissingFastPiece
   }
 }
 
+#endif // ENABLE_BITTORRENT
+
 PieceHandle DefaultPieceStorage::getMissingPiece()
 {
   size_t index;
@@ -353,12 +362,6 @@ bool DefaultPieceStorage::isSelectiveDownloadingMode()
   return bitfieldMan->isFilterEnabled();
 }
 
-void DefaultPieceStorage::finishSelectiveDownloadingMode()
-{
-  bitfieldMan->clearFilter();
-  diskAdaptor->addAllDownloadEntry();
-}
-
 // not unittested
 void DefaultPieceStorage::cancelPiece(const PieceHandle& piece)
 {
@@ -415,45 +418,34 @@ size_t DefaultPieceStorage::getInFlightPieceCompletedLength() const
 }
 
 // not unittested
-void DefaultPieceStorage::setFileFilter(const std::deque<std::string>& filePaths)
+void DefaultPieceStorage::setupFileFilter()
 {
-  if(downloadContext->getFileMode() != DownloadContext::MULTI || filePaths.empty()) {
+  std::deque<SharedHandle<FileEntry> > fileEntries =
+    downloadContext->getFileEntries();
+  bool allSelected = true;
+  for(std::deque<SharedHandle<FileEntry> >::const_iterator i =
+	fileEntries.begin(); i != fileEntries.end(); ++i) {
+    if(!(*i)->isRequested()) {
+      allSelected = false;
+      break;
+    }
+  }
+  if(allSelected) {
     return;
   }
-  diskAdaptor->removeAllDownloadEntry();
-  for(std::deque<std::string>::const_iterator pitr = filePaths.begin();
-      pitr != filePaths.end(); pitr++) {
-    if(!diskAdaptor->addDownloadEntry(*pitr)) {
-      throw DlAbortEx(StringFormat(EX_NO_SUCH_FILE_ENTRY, (*pitr).c_str()).str());
+  for(std::deque<SharedHandle<FileEntry> >::const_iterator i =
+	fileEntries.begin(); i != fileEntries.end(); ++i) {
+    if((*i)->isRequested()) {
+      bitfieldMan->addFilter((*i)->getOffset(), (*i)->getLength());
     }
-    FileEntryHandle fileEntry = diskAdaptor->getFileEntryFromPath(*pitr);
-    bitfieldMan->addFilter(fileEntry->getOffset(), fileEntry->getLength());
   }
   bitfieldMan->enableFilter();
 }
 
-void DefaultPieceStorage::setFileFilter(IntSequence seq)
-{
-  std::deque<int32_t> fileIndexes = seq.flush();
-  // TODO Is sorting necessary?
-  std::sort(fileIndexes.begin(), fileIndexes.end());
-  fileIndexes.erase(std::unique(fileIndexes.begin(), fileIndexes.end()), fileIndexes.end());
-  std::deque<std::string> filePaths;
-  const FileEntries& entries = diskAdaptor->getFileEntries();
-  for(size_t i = 0; i < entries.size(); i++) {
-    if(std::find(fileIndexes.begin(), fileIndexes.end(), i+1) != fileIndexes.end()) {
-      logger->debug("index=%d is %s", i+1, entries[i]->getPath().c_str());
-      filePaths.push_back(entries[i]->getPath());
-    }
-  }
-  setFileFilter(filePaths);
-}
-
 // not unittested
 void DefaultPieceStorage::clearFileFilter()
 {
   bitfieldMan->clearFilter();
-  diskAdaptor->addAllDownloadEntry();
 }
 
 // not unittested
@@ -474,36 +466,35 @@ void DefaultPieceStorage::initStorage()
 {
   if(downloadContext->getFileMode() == DownloadContext::SINGLE) {
     logger->debug("Instantiating DirectDiskAdaptor");
-    DiskWriterHandle writer = _diskWriterFactory->newDiskWriter();
-    writer->setDirectIOAllowed(option->getAsBool(PREF_ENABLE_DIRECT_IO));
     DirectDiskAdaptorHandle directDiskAdaptor(new DirectDiskAdaptor());
-    directDiskAdaptor->setDiskWriter(writer);
     directDiskAdaptor->setTotalLength(downloadContext->getTotalLength());
+    directDiskAdaptor->setFileEntries(downloadContext->getFileEntries());
+
+    DiskWriterHandle writer =
+      _diskWriterFactory->newDiskWriter(directDiskAdaptor->getFilePath());
+    if(option->getAsBool(PREF_ENABLE_DIRECT_IO)) {
+      writer->allowDirectIO();
+    }
+
+    directDiskAdaptor->setDiskWriter(writer);
     this->diskAdaptor = directDiskAdaptor;
   } else {
     // file mode == DownloadContext::MULTI
-    if(option->getAsBool(PREF_DIRECT_FILE_MAPPING)) {
-      logger->debug("Instantiating MultiDiskAdaptor");
-      MultiDiskAdaptorHandle multiDiskAdaptor(new MultiDiskAdaptor());
-      multiDiskAdaptor->setDirectIOAllowed(option->getAsBool(PREF_ENABLE_DIRECT_IO));
-      multiDiskAdaptor->setPieceLength(downloadContext->getPieceLength());
-      multiDiskAdaptor->setTopDir(downloadContext->getName());
-      multiDiskAdaptor->setMaxOpenFiles(option->getAsInt(PREF_BT_MAX_OPEN_FILES));
-      this->diskAdaptor = multiDiskAdaptor;
-    } else {
-      logger->debug("Instantiating CopyDiskAdaptor");
-      DiskWriterHandle writer = _diskWriterFactory->newDiskWriter();
-      writer->setDirectIOAllowed(option->getAsBool(PREF_ENABLE_DIRECT_IO));
-      CopyDiskAdaptorHandle copyDiskAdaptor(new CopyDiskAdaptor());
-      copyDiskAdaptor->setDiskWriter(writer);
-      copyDiskAdaptor->setTempFilename(downloadContext->getName()+".a2tmp");
-      copyDiskAdaptor->setTotalLength(downloadContext->getTotalLength());
-      copyDiskAdaptor->setTopDir(downloadContext->getName());
-      this->diskAdaptor = copyDiskAdaptor;
+    logger->debug("Instantiating MultiDiskAdaptor");
+    MultiDiskAdaptorHandle multiDiskAdaptor(new MultiDiskAdaptor());
+    multiDiskAdaptor->setFileEntries(downloadContext->getFileEntries());
+    if(option->getAsBool(PREF_ENABLE_DIRECT_IO)) {
+      multiDiskAdaptor->allowDirectIO();
     }
+    multiDiskAdaptor->setPieceLength(downloadContext->getPieceLength());
+    multiDiskAdaptor->setMaxOpenFiles(option->getAsInt(PREF_BT_MAX_OPEN_FILES));
+    this->diskAdaptor = multiDiskAdaptor;
   }
-  diskAdaptor->setStoreDir(downloadContext->getDir());
-  diskAdaptor->setFileEntries(downloadContext->getFileEntries());
+#ifdef HAVE_POSIX_FALLOCATE
+  if(option->get(PREF_FILE_ALLOCATION) == V_FALLOC) {
+    diskAdaptor->enableFallocate();
+  }
+#endif // HAVE_POSIX_FALLOCATE
 }
 
 void DefaultPieceStorage::setBitfield(const unsigned char* bitfield,
@@ -643,26 +634,26 @@ void DefaultPieceStorage::setDiskWriterFactory(const DiskWriterFactoryHandle& di
 void DefaultPieceStorage::addPieceStats(const unsigned char* bitfield,
 					size_t bitfieldLength)
 {
-  _pieceSelector->addPieceStats(bitfield, bitfieldLength);
+  _pieceStatMan->addPieceStats(bitfield, bitfieldLength);
 }
 
 void DefaultPieceStorage::subtractPieceStats(const unsigned char* bitfield,
 					     size_t bitfieldLength)
 {
-  _pieceSelector->subtractPieceStats(bitfield, bitfieldLength);
+  _pieceStatMan->subtractPieceStats(bitfield, bitfieldLength);
 }
 
 void DefaultPieceStorage::updatePieceStats(const unsigned char* newBitfield,
 					   size_t newBitfieldLength,
 					   const unsigned char* oldBitfield)
 {
-  _pieceSelector->updatePieceStats(newBitfield, newBitfieldLength,
+  _pieceStatMan->updatePieceStats(newBitfield, newBitfieldLength,
 				   oldBitfield);
 }
 
 void DefaultPieceStorage::addPieceStats(size_t index)
 {
-  _pieceSelector->addPieceStats(index);
+  _pieceStatMan->addPieceStats(index);
 }
 
 } // namespace aria2
