@@ -36,23 +36,31 @@
 #define _D_DL_ABORT_EX_H_
 #include "RecoverableException.h"
 
-class DlAbortEx : public RecoverableException {
+namespace aria2 {
+
+class DlAbortEx:public RecoverableException {
+protected:
+  virtual SharedHandle<Exception> copy() const
+  {
+    SharedHandle<Exception> e(new DlAbortEx(*this));
+    return e;
+  }
 public:
-  DlAbortEx(Exception* cause = 0):RecoverableException(cause) {}
-
-  DlAbortEx(const char* msg, ...) {
-    va_list ap;
-    va_start(ap, msg);
-    setMsg(string(msg), ap);
-    va_end(ap);
-  }
-
-  DlAbortEx(Exception* cause, const char* msg, ...):RecoverableException(cause) {
-    va_list ap;
-    va_start(ap, msg);
-    setMsg(string(msg), ap);
-    va_end(ap);
-  }
+  DlAbortEx(const char* file, int line, const std::string& msg):
+    RecoverableException(file, line, msg) {}
+  DlAbortEx(const char* file, int line, const std::string& msg,
+	    const Exception& cause):
+    RecoverableException(file, line, msg, cause) {}
+  DlAbortEx(const char* file, int line, const RecoverableException& e):
+    RecoverableException(file, line, e) {}
+  DlAbortEx(const char* file, int line, const std::string& msg,
+	    DownloadResult::RESULT code):
+    RecoverableException(file, line, msg, code) {}
 };
 
+#define DL_ABORT_EX(arg) DlAbortEx(__FILE__, __LINE__, arg)
+#define DL_ABORT_EX2(arg1, arg2) DlAbortEx(__FILE__, __LINE__, arg1, arg2)
+
+} // namespace aria2
+
 #endif // _D_DL_ABORT_EX_H_
