@@ -81,8 +81,6 @@ public:
 
   virtual std::deque<SharedHandle<FileEntry> > getFileEntries() const = 0;
 
-  virtual const std::string& getName() const = 0;
-  
   virtual size_t getPieceLength() const = 0;
 
   virtual size_t getNumPieces() const = 0;
@@ -99,7 +97,10 @@ public:
    */
   virtual std::string getActualBasePath() const = 0;
 
-  const std::string& getDir() const;
+  const std::string& getDir() const
+  {
+    return _dir;
+  }
 
   void setDir(const std::string& dir);
 
