@@ -45,6 +45,8 @@
 #include "FileAllocationMan.h"
 #ifdef ENABLE_MESSAGE_DIGEST
 # include "CheckIntegrityMan.h"
+# include "CheckIntegrityEntry.h"
+# include "CheckIntegrityDispatcherCommand.h"
 #endif // ENABLE_MESSAGE_DIGEST
 #include "prefs.h"
 #include "FillRequestGroupCommand.h"
@@ -54,6 +56,16 @@
 #include "TimedHaltCommand.h"
 #include "DownloadResult.h"
 #include "ServerStatMan.h"
+#include "a2io.h"
+#ifdef HAVE_EPOLL
+# include "EpollEventPoll.h"
+#endif // HAVE_EPOLL
+#include "SelectEventPoll.h"
+#include "DlAbortEx.h"
+#include "FileAllocationEntry.h"
+#ifdef ENABLE_XML_RPC
+# include "HttpListenCommand.h"
+#endif // ENABLE_XML_RPC
 
 namespace aria2 {
 
@@ -79,7 +91,24 @@ DownloadEngineFactory::newDownloadEngine(Option* op,
     workingSet = requestGroups;
   }
 
-  DownloadEngineHandle e(new DownloadEngine());
+  SharedHandle<EventPoll> eventPoll;
+#ifdef HAVE_EPOLL
+  if(op->get(PREF_EVENT_POLL) == V_EPOLL) {
+    SharedHandle<EpollEventPoll> ep(new EpollEventPoll());
+    if(ep->good()) {
+      eventPoll = ep;
+    } else {
+      throw DL_ABORT_EX("Initializing EpollEventPoll failed."
+		      " Try --event-poll=select");
+    }
+  } else
+#endif // HAVE_EPLL
+    if(op->get(PREF_EVENT_POLL) == V_SELECT) {
+      eventPoll.reset(new SelectEventPoll());
+    } else {
+      abort();
+    }
+  DownloadEngineHandle e(new DownloadEngine(eventPoll));
   e->option = op;
 
   RequestGroupManHandle
@@ -92,8 +121,13 @@ DownloadEngineFactory::newDownloadEngine(Option* op,
   e->_checkIntegrityMan.reset(new CheckIntegrityMan());
 #endif // ENABLE_MESSAGE_DIGEST
   e->addRoutineCommand(new FillRequestGroupCommand(e->newCUID(), e.get(), 1));
-  e->addRoutineCommand(new FileAllocationDispatcherCommand(e->newCUID(),
-							   e.get()));
+  e->addRoutineCommand(new FileAllocationDispatcherCommand
+		       (e->newCUID(), e->_fileAllocationMan, e.get()));
+#ifdef ENABLE_MESSAGE_DIGEST
+  e->addRoutineCommand(new CheckIntegrityDispatcherCommand
+		       (e->newCUID(), e->_checkIntegrityMan, e.get()));
+#endif // ENABLE_MESSAGE_DIGEST
+
   if(op->getAsInt(PREF_AUTO_SAVE_INTERVAL) > 0) {
     e->addRoutineCommand
       (new AutoSaveCommand(e->newCUID(), e.get(),
@@ -107,6 +141,17 @@ DownloadEngineFactory::newDownloadEngine(Option* op,
 						stopSec));
     }
   }
+#ifdef ENABLE_XML_RPC
+  if(op->getAsBool(PREF_ENABLE_XML_RPC)) {
+    HttpListenCommand* httpListenCommand =
+      new HttpListenCommand(e->newCUID(), e.get());
+    if(httpListenCommand->bindPort(op->getAsInt(PREF_XML_RPC_LISTEN_PORT))){
+      e->addRoutineCommand(httpListenCommand);
+    } else {
+      delete httpListenCommand;
+    }
+  }
+#endif // ENABLE_XML_RPC
   return e;
 }
 
