@@ -67,6 +67,7 @@ Command* HttpInitiateConnectionCommand::createNextCommand
   if(!proxyRequest.isNull()) {
     SharedHandle<SocketCore> pooledSocket =
       e->popPooledSocket(req->getHost(), req->getPort());
+    std::string proxyMethod = resolveProxyMethod(req->getProtocol());
     if(pooledSocket.isNull()) {
       logger->info(MSG_CONNECTING_TO_SERVER, cuid,
 		   proxyRequest->getHost().c_str(), proxyRequest->getPort());
@@ -74,12 +75,12 @@ Command* HttpInitiateConnectionCommand::createNextCommand
       socket->establishConnection(resolvedAddresses.front(),
 				  proxyRequest->getPort());
 
-      if(useProxyTunnel()) {
+      if(proxyMethod == V_TUNNEL) {
 	command = new HttpProxyRequestCommand(cuid, req, _requestGroup, e,
 					      proxyRequest, socket);
-      } else if(useProxyGet()) {
+      } else if(proxyMethod == V_GET) {
 	SharedHandle<HttpConnection> httpConnection
-	  (new HttpConnection(cuid, socket, e->option));
+	  (new HttpConnection(cuid, socket, getOption().get()));
 	HttpRequestCommand* c = new HttpRequestCommand(cuid, req, _requestGroup,
 						       httpConnection, e,
 						       socket);
@@ -87,15 +88,15 @@ Command* HttpInitiateConnectionCommand::createNextCommand
 	command = c;
       } else {
 	// TODO
-	throw DlAbortEx("ERROR");
+	throw DL_ABORT_EX("ERROR");
       }
     } else {
       SharedHandle<HttpConnection> httpConnection
-	(new HttpConnection(cuid, pooledSocket, e->option));
+	(new HttpConnection(cuid, pooledSocket, getOption().get()));
       HttpRequestCommand* c = new HttpRequestCommand(cuid, req, _requestGroup,
 						     httpConnection, e,
 						     pooledSocket);
-      if(useProxyGet()) {
+      if(proxyMethod == V_GET) {
 	c->setProxyRequest(proxyRequest);
       }
       command = c;
@@ -111,21 +112,11 @@ Command* HttpInitiateConnectionCommand::createNextCommand
     } else {
       socket = pooledSocket;
     }
-    SharedHandle<HttpConnection> httpConnection(new HttpConnection(cuid, socket, e->option));
+    SharedHandle<HttpConnection> httpConnection(new HttpConnection(cuid, socket, getOption().get()));
     command = new HttpRequestCommand(cuid, req, _requestGroup, httpConnection,
 				     e, socket);
   }
   return command;
 }
 
-bool HttpInitiateConnectionCommand::useProxyGet() const
-{
-  return e->option->get(PREF_PROXY_METHOD) == V_GET;
-}
-
-bool HttpInitiateConnectionCommand::useProxyTunnel() const
-{
-  return e->option->get(PREF_PROXY_METHOD) == V_TUNNEL;
-}
-
 } // namespace aria2
