@@ -34,13 +34,20 @@
 /* copyright --> */
 #include "HttpProxyRequestCommand.h"
 #include "HttpProxyResponseCommand.h"
+#include "Request.h"
+#include "Socket.h"
 
-HttpProxyRequestCommand::HttpProxyRequestCommand(int cuid,
-						 const RequestHandle& req,
-						 RequestGroup* requestGroup,
-						 DownloadEngine* e,
-						 const SocketHandle& s)
-  :AbstractProxyRequestCommand(cuid, req, requestGroup, e, s) {}
+namespace aria2 {
+
+HttpProxyRequestCommand::HttpProxyRequestCommand
+(int cuid,
+ const RequestHandle& req,
+ RequestGroup* requestGroup,
+ DownloadEngine* e,
+ const SharedHandle<Request>& proxyRequest,
+ const SocketHandle& s)
+  :
+  AbstractProxyRequestCommand(cuid, req, requestGroup, e, proxyRequest, s) {}
 
 HttpProxyRequestCommand::~HttpProxyRequestCommand() {}
 
@@ -48,3 +55,5 @@ Command* HttpProxyRequestCommand::getNextCommand()
 {
   return new HttpProxyResponseCommand(cuid, req, _requestGroup, httpConnection, e, socket);
 }
+
+} // namespace aria2
