@@ -33,10 +33,16 @@
  */
 /* copyright --> */
 #include "IteratableChunkChecksumValidator.h"
+
+#include <cerrno>
+#include <cstring>
+#include <cstdlib>
+
 #include "Util.h"
 #include "message.h"
 #include "MessageDigestHelper.h"
 #include "DiskAdaptor.h"
+#include "FileEntry.h"
 #include "RecoverableException.h"
 #include "DownloadContext.h"
 #include "PieceStorage.h"
@@ -44,7 +50,9 @@
 #include "LogFactory.h"
 #include "Logger.h"
 #include "messageDigest.h"
-#include <cerrno>
+#include "StringFormat.h"
+
+namespace aria2 {
 
 #define BUFSIZE (256*1024)
 #define ALIGNMENT 512
@@ -57,51 +65,52 @@ IteratableChunkChecksumValidator(const DownloadContextHandle& dctx,
   _bitfield(new BitfieldMan(_dctx->getPieceLength(), _dctx->getTotalLength())),
   _currentIndex(0),
   _logger(LogFactory::getInstance()),
-  _ctx(0),
   _buffer(0) {}
 
 IteratableChunkChecksumValidator::~IteratableChunkChecksumValidator()
 {
+#ifdef HAVE_POSIX_MEMALIGN
+  free(_buffer);
+#else // !HAVE_POSIX_MEMALIGN
   delete [] _buffer;
+#endif // !HAVE_POSIX_MEMALIGN
 }
 
 
 void IteratableChunkChecksumValidator::validateChunk()
 {
   if(!finished()) {
-    string actualChecksum;
+    std::string actualChecksum;
     try {
       actualChecksum = calculateActualChecksum();
-    } catch(RecoverableException* ex) {
+      if(actualChecksum == _dctx->getPieceHashes()[_currentIndex]) {
+	_bitfield->setBit(_currentIndex);
+      } else {
+	_logger->info(EX_INVALID_CHUNK_CHECKSUM,
+		      _currentIndex,
+		      Util::itos(getCurrentOffset(), true).c_str(),
+		      _dctx->getPieceHashes()[_currentIndex].c_str(),
+		      actualChecksum.c_str());
+	_bitfield->unsetBit(_currentIndex);
+      }
+    } catch(RecoverableException& ex) {
       _logger->debug("Caught exception while validating piece index=%d. Some part of file may be missing. Continue operation.", ex, _currentIndex);
-      delete ex;
-      _bitfield->unsetBit(_currentIndex);
-      _currentIndex++;
-      return;
-    }
-    if(actualChecksum == _dctx->getPieceHashes()[_currentIndex]) {
-      _bitfield->setBit(_currentIndex);
-    } else {
-      _logger->info(EX_INVALID_CHUNK_CHECKSUM,
-		    _currentIndex,
-		    Util::llitos(getCurrentOffset(), true).c_str(),
-		    _dctx->getPieceHashes()[_currentIndex].c_str(),
-		    actualChecksum.c_str());
       _bitfield->unsetBit(_currentIndex);
     }
-    _currentIndex++;
+
+    ++_currentIndex;
     if(finished()) {
       _pieceStorage->setBitfield(_bitfield->getBitfield(), _bitfield->getBitfieldLength());
     }
   }
 }
 
-string IteratableChunkChecksumValidator::calculateActualChecksum()
+std::string IteratableChunkChecksumValidator::calculateActualChecksum()
 {
-  int64_t offset = getCurrentOffset();
-  int32_t length;
+  off_t offset = getCurrentOffset();
+  size_t length;
   // When validating last piece
-  if(_currentIndex+1 == (uint32_t)_dctx->getNumPieces()) {
+  if(_currentIndex+1 == _dctx->getNumPieces()) {
     length = _dctx->getTotalLength()-offset;
   } else {
     length = _dctx->getPieceLength();
@@ -112,40 +121,43 @@ string IteratableChunkChecksumValidator::calculateActualChecksum()
 void IteratableChunkChecksumValidator::init()
 {
 #ifdef HAVE_POSIX_MEMALIGN
+  free(_buffer);
   _buffer = (unsigned char*)Util::allocateAlignedMemory(ALIGNMENT, BUFSIZE);
-#else
+#else // !HAVE_POSIX_MEMALIGN
+  delete [] _buffer;
   _buffer = new unsigned char[BUFSIZE];
-#endif // HAVE_POSIX_MEMALIGN
+#endif // !HAVE_POSIX_MEMALIGN
   if(_dctx->getFileEntries().size() == 1) {
     _pieceStorage->getDiskAdaptor()->enableDirectIO();
   }
-  _ctx = new MessageDigestContext();
+  _ctx.reset(new MessageDigestContext());
   _ctx->trySetAlgo(_dctx->getPieceHashAlgo());
   _ctx->digestInit();
   _bitfield->clearAllBit();
   _currentIndex = 0;
 }
 
-string IteratableChunkChecksumValidator::digest(int64_t offset, int32_t length)
+std::string IteratableChunkChecksumValidator::digest(off_t offset, size_t length)
 {
   _ctx->digestReset();
-  int64_t curoffset = offset/ALIGNMENT*ALIGNMENT;
-  int64_t max = offset+length;
-  int32_t woffset;
+  off_t curoffset = offset/ALIGNMENT*ALIGNMENT;
+  off_t max = offset+length;
+  off_t woffset;
   if(curoffset < offset) {
     woffset = offset-curoffset;
   } else {
     woffset = 0;
   }
   while(curoffset < max) {
-    int32_t r = _pieceStorage->getDiskAdaptor()->readData(_buffer, BUFSIZE,
-							  curoffset);
-    if(r == 0) {
-      throw new DlAbortEx(EX_FILE_READ, _dctx->getActualBasePath().c_str(),
-			  strerror(errno));
+    size_t r = _pieceStorage->getDiskAdaptor()->readData(_buffer, BUFSIZE,
+							 curoffset);
+    if(r == 0 || r < static_cast<size_t>(woffset)) {
+      throw DL_ABORT_EX
+	(StringFormat(EX_FILE_READ, _dctx->getActualBasePath().c_str(),
+		      strerror(errno)).str());
     }
-    int32_t wlength;
-    if(max < curoffset+r) {
+    size_t wlength;
+    if(max < static_cast<off_t>(curoffset+r)) {
       wlength = max-curoffset-woffset;
     } else {
       wlength = r-woffset;
@@ -160,7 +172,7 @@ string IteratableChunkChecksumValidator::digest(int64_t offset, int32_t length)
 
 bool IteratableChunkChecksumValidator::finished() const
 {
-  if(_currentIndex >= (uint32_t)_dctx->getNumPieces()) {
+  if(_currentIndex >= _dctx->getNumPieces()) {
     _pieceStorage->getDiskAdaptor()->disableDirectIO();
     return true;
   } else {
@@ -168,12 +180,14 @@ bool IteratableChunkChecksumValidator::finished() const
   }
 }
 
-int64_t IteratableChunkChecksumValidator::getCurrentOffset() const
+off_t IteratableChunkChecksumValidator::getCurrentOffset() const
 {
-  return (int64_t)_currentIndex*_dctx->getPieceLength();
+  return (off_t)_currentIndex*_dctx->getPieceLength();
 }
 
-int64_t IteratableChunkChecksumValidator::getTotalLength() const
+uint64_t IteratableChunkChecksumValidator::getTotalLength() const
 {
   return _dctx->getTotalLength();
 }
+
+} // namespace aria2
