@@ -36,68 +36,72 @@
 #define _D_METALINK_ENTRY_H_
 
 #include "common.h"
-#include "MetalinkResource.h"
-#include "FileEntry.h"
-#ifdef ENABLE_MESSAGE_DIGEST
-# include "Checksum.h"
-# include "ChunkChecksum.h"
-#endif // ENABLE_MESSAGE_DIGEST
+
+#include <string>
 #include <deque>
 
-class MetalinkEntry;
+#include "SharedHandle.h"
 
-typedef SharedHandle<MetalinkEntry> MetalinkEntryHandle;
-typedef deque<MetalinkEntryHandle> MetalinkEntries;
+namespace aria2 {
+
+class MetalinkResource;
+class FileEntry;
+#ifdef ENABLE_MESSAGE_DIGEST
+class Checksum;
+class ChunkChecksum;
+#endif // ENABLE_MESSAGE_DIGEST
+class Signature;
 
 class MetalinkEntry {
 public:
-  FileEntryHandle file;
-  string version;
-  string language;
-  string os;
-  MetalinkResources resources;
-  int32_t maxConnections;
+  SharedHandle<FileEntry> file;
+  std::string version;
+  std::string language;
+  std::string os;
+  std::deque<SharedHandle<MetalinkResource> > resources;
+  int maxConnections;
 #ifdef ENABLE_MESSAGE_DIGEST
-  ChecksumHandle checksum;
-  ChunkChecksumHandle chunkChecksum;
+  SharedHandle<Checksum> checksum;
+  SharedHandle<ChunkChecksum> chunkChecksum;
 #endif // ENABLE_MESSAGE_DIGEST
+private:
+  SharedHandle<Signature> _signature;
 public:
   MetalinkEntry();
 
   ~MetalinkEntry();
 
-  MetalinkEntry& operator=(const MetalinkEntry& metalinkEntry) {
-    if(this != &metalinkEntry) {
-      this->file = metalinkEntry.file;
-      this->version = metalinkEntry.version;
-      this->language = metalinkEntry.language;
-      this->os = metalinkEntry.os;
-      this->maxConnections = metalinkEntry.maxConnections;
-#ifdef ENABLE_MESSAGE_DIGEST
-      this->checksum = metalinkEntry.checksum;
-      this->chunkChecksum = metalinkEntry.chunkChecksum;
-#endif // ENABLE_MESSAGE_DIGEST
-    }
-    return *this;
-  }
+  MetalinkEntry& operator=(const MetalinkEntry& metalinkEntry);
 
-  string getPath() const
-  {
-    return file->getPath();
-  }
+  std::string getPath() const;
 
-  int64_t getLength() const
+  uint64_t getLength() const;
+
+  const SharedHandle<FileEntry>& getFile() const
   {
-    return file->getLength();
+    return file;
   }
 
   void dropUnsupportedResource();
 
   void reorderResourcesByPreference();
   
-  void setLocationPreference(const Strings& locations, int32_t preferenceToAdd);
+  void setLocationPreference(const std::deque<std::string>& locations, int preferenceToAdd);
+  void setProtocolPreference(const std::string& protocol, int preferenceToAdd);
+
+  static void toFileEntry
+  (std::deque<SharedHandle<FileEntry> >& fileEntries,
+   const std::deque<SharedHandle<MetalinkEntry> >& metalinkEntries);
+
+  void setSignature(const SharedHandle<Signature>& signature);
+
+  const SharedHandle<Signature>& getSignature() const
+  {
+    return _signature;
+  }
 
-  static FileEntries toFileEntry(const MetalinkEntries& metalinkEntries);
 };
 
+} // namespace aria2
+
 #endif // _D_METALINK_ENTRY_H_
