@@ -55,27 +55,36 @@ public:
 
   ~DiskWriterEntry();
 
-  std::string getFilePath(const std::string& topDir) const;
+  const std::string& getFilePath() const;
 
-  void initAndOpenFile(const std::string& topDir);
+  void initAndOpenFile();
 
-  void openFile(const std::string& topDir);
+  void openFile();
 
-  void openExistingFile(const std::string& topDir);
+  void openExistingFile();
 
   void closeFile();
 
-  bool isOpen() const;
+  bool isOpen() const
+  {
+    return _open;
+  }
 
-  bool fileExists(const std::string& topDir);
+  bool fileExists();
 
   uint64_t size() const;
 
-  SharedHandle<FileEntry> getFileEntry() const;
+  const SharedHandle<FileEntry>& getFileEntry() const
+  {
+    return fileEntry;
+  }
 
   void setDiskWriter(const SharedHandle<DiskWriter>& diskWriter);
 
-  SharedHandle<DiskWriter> getDiskWriter() const;
+  const SharedHandle<DiskWriter>& getDiskWriter() const
+  {
+    return diskWriter;
+  }
 
   bool operator<(const DiskWriterEntry& entry) const;
 
@@ -89,9 +98,16 @@ public:
   // called.
   void disableDirectIO();
 
-  bool needsFileAllocation() const;
+  bool needsFileAllocation() const
+  {
+    return _needsFileAllocation;
+  }
+
+  void needsFileAllocation(bool f)
+  {
+    _needsFileAllocation = f;
+  }
 
-  void needsFileAllocation(bool f);
 };
 
 typedef SharedHandle<DiskWriterEntry> DiskWriterEntryHandle;
@@ -101,27 +117,23 @@ typedef std::deque<DiskWriterEntryHandle> DiskWriterEntries;
 class MultiDiskAdaptor : public DiskAdaptor {
   friend class MultiFileAllocationIterator;
 private:
-  std::string topDir;
   size_t pieceLength;
   DiskWriterEntries diskWriterEntries;
 
-  std::string _cachedTopDirPath;
-
   std::deque<SharedHandle<DiskWriterEntry> > _openedDiskWriterEntries;
 
   size_t _maxOpenFiles;
 
   bool _directIOAllowed;
 
+  bool _readOnly;
+
   void resetDiskWriterEntries();
 
-  void mkdir(const std::string& topDirPath) const;
-
-  std::string getTopDirPath() const;
+  void mkdir() const;
 
   void openIfNot(const SharedHandle<DiskWriterEntry>& entry,
-		 void (DiskWriterEntry::*f)(const std::string&),
-		 const std::string& topDirPath);
+		 void (DiskWriterEntry::*f)());
  
   static const size_t DEFAULT_MAX_OPEN_FILES = 100;
 
@@ -147,11 +159,6 @@ public:
 
   virtual bool fileExists();
 
-  virtual std::string getFilePath()
-  {
-    return getTopDirPath();
-  }
-
   virtual uint64_t size();
 
   virtual SharedHandle<FileAllocationIterator> fileAllocationIterator();
@@ -160,13 +167,11 @@ public:
 
   virtual void disableDirectIO();
 
-  void setTopDir(const std::string& topDir) {
-    this->topDir = topDir;
-  }
+  virtual void enableReadOnly();
 
-  const std::string& getTopDir() const {
-    return topDir;
-  }
+  virtual void disableReadOnly();
+
+  virtual bool isReadOnlyEnabled() const { return _readOnly; }
 
   void setPieceLength(size_t pieceLength) {
     this->pieceLength = pieceLength;
@@ -176,14 +181,9 @@ public:
     return pieceLength;
   }
 
-  virtual bool directIOAllowed() const
+  void allowDirectIO()
   {
-    return _directIOAllowed;
-  }
-
-  void setDirectIOAllowed(bool b)
-  {
-    _directIOAllowed = b;
+    _directIOAllowed = true;
   }
 
   virtual void cutTrailingGarbage();
@@ -193,7 +193,11 @@ public:
   virtual size_t utime(const Time& actime, const Time& modtime);
 
   const std::deque<SharedHandle<DiskWriterEntry> >&
-  getDiskWriterEntries() const;
+  getDiskWriterEntries() const
+  {
+    return diskWriterEntries;
+  }
+
 };
 
 typedef SharedHandle<MultiDiskAdaptor> MultiDiskAdaptorHandle;
