@@ -37,29 +37,51 @@
 
 #include "common.h"
 
+#include <deque>
+#include <iosfwd>
+
+#include "SharedHandle.h"
+#include "DownloadResult.h"
+
+namespace aria2 {
+
 class RequestGroup;
-typedef SharedHandle<RequestGroup> RequestGroupHandle;
-typedef deque<RequestGroupHandle> RequestGroups;
 class Option;
 class Logger;
+class StatCalc;
 
 class MultiUrlRequestInfo {
 private:
-  RequestGroups _requestGroups;
+  std::deque<SharedHandle<RequestGroup> > _requestGroups;
 
-  Option* _option;
+  SharedHandle<Option> _option;
 
-  const Logger* _logger;
+  SharedHandle<StatCalc> _statCalc;
+
+  std::ostream& _summaryOut;
+
+  Logger* _logger;
 
   void printMessageForContinue();
 
 public:
-  MultiUrlRequestInfo(const RequestGroups& requestGroups, Option* op);
+  MultiUrlRequestInfo
+  (const std::deque<SharedHandle<RequestGroup> >& requestGroups,
+   const SharedHandle<Option>& op,
+   const SharedHandle<StatCalc>& statCalc,
+   std::ostream& summaryOut);
   
   virtual ~MultiUrlRequestInfo();
 
-  void execute();
+  /**
+   * Returns FINISHED if all downloads have completed, otherwise returns the
+   * last download result.
+   */
+  DownloadResult::RESULT execute();
 };
 
 typedef SharedHandle<MultiUrlRequestInfo> MultiUrlRequestInfoHandle;
+
+} // namespace aria2
+
 #endif // _D_MULTI_URL_REQUEST_INFO_H_
