@@ -36,20 +36,19 @@
 #define _D_PEER_INTERACTION_COMMAND_H_
 
 #include "PeerAbstractCommand.h"
-#include "RequestGroupAware.h"
 
 namespace aria2 {
 
+class RequestGroup;
 class BtContext;
 class BtInteractive;
 class PeerConnection;
 class BtRuntime;
 class PeerStorage;
 class PieceStorage;
+class Option;
 
-class PeerInteractionCommand : public PeerAbstractCommand,
-			       public RequestGroupAware
-{
+class PeerInteractionCommand : public PeerAbstractCommand {
 public:
   enum Seq {
     INITIATOR_SEND_HANDSHAKE,
@@ -57,6 +56,8 @@ public:
     RECEIVER_WAIT_HANDSHAKE,
     WIRED};
 private:
+  RequestGroup* _requestGroup;
+
   SharedHandle<BtContext> _btContext;
 
   SharedHandle<BtRuntime> _btRuntime;
@@ -67,7 +68,8 @@ private:
 
   Seq sequence;
   SharedHandle<BtInteractive> btInteractive;
-  unsigned int maxDownloadSpeedLimit;
+
+  const SharedHandle<Option>& getOption() const;
 protected:
   virtual bool executeInternal();
   virtual bool prepareForNextPeer(time_t wait);
