@@ -67,15 +67,10 @@ PeerReceiveHandshakeCommand::PeerReceiveHandshakeCommand
  const SharedHandle<PeerConnection>& peerConnection)
   :
   PeerAbstractCommand(cuid, peer, e, s),
-  _peerConnection(peerConnection),
-  _thresholdSpeed(e->option->getAsInt(PREF_BT_REQUEST_PEER_SPEED_LIMIT))
+  _peerConnection(peerConnection)
 {
   if(_peerConnection.isNull()) {
-    _peerConnection.reset(new PeerConnection(cuid, socket, e->option));
-  }
-  unsigned int maxDownloadSpeed = e->option->getAsInt(PREF_MAX_DOWNLOAD_LIMIT);
-  if(maxDownloadSpeed > 0) {
-    _thresholdSpeed = std::min(maxDownloadSpeed, _thresholdSpeed);
+    _peerConnection.reset(new PeerConnection(cuid, socket));
   }
 }
 
@@ -107,12 +102,21 @@ bool PeerReceiveHandshakeCommand::executeInternal()
       btRegistry->getPeerStorage(infoHash);
 
     if(btContext.isNull() || !btRuntime->ready()) {
-      throw DlAbortEx
+      throw DL_ABORT_EX
 	(StringFormat("Unknown info hash %s", infoHash.c_str()).str());
     }
     TransferStat tstat = btContext->getOwnerRequestGroup()->calculateStat();
+    const unsigned int maxDownloadLimit =
+      btContext->getOwnerRequestGroup()->getMaxDownloadSpeedLimit();
+    unsigned int thresholdSpeed =
+      btContext->getOwnerRequestGroup()->
+      getOption()->getAsInt(PREF_BT_REQUEST_PEER_SPEED_LIMIT);
+    if(maxDownloadLimit > 0) {
+      thresholdSpeed = std::min(maxDownloadLimit, thresholdSpeed);
+    }
+
     if((!pieceStorage->downloadFinished() &&
-       tstat.getDownloadSpeed() < _thresholdSpeed) ||
+	tstat.getDownloadSpeed() < thresholdSpeed) ||
        btRuntime->lessThanMaxPeers()) {
       if(peerStorage->addPeer(peer)) {
 
