@@ -36,22 +36,26 @@
 #define _D_PIECE_STORAGE_H_
 
 #include "common.h"
-#include "SharedHandle.h"
-#include "TimeA2.h"
-#include "IntSequence.h"
+
 #include <string>
 #include <deque>
 
+#include "SharedHandle.h"
+#include "TimeA2.h"
+
 namespace aria2 {
 
 class Piece;
+#ifdef ENABLE_BITTORRENT
 class Peer;
+#endif // ENABLE_BITTORRENT
 class DiskAdaptor;
 
 class PieceStorage {
 public:
   virtual ~PieceStorage() {}
 
+#ifdef ENABLE_BITTORRENT
   /**
    * Returns true if the peer has a piece that localhost doesn't have.
    * Otherwise returns false.
@@ -93,6 +97,8 @@ public:
   (const SharedHandle<Peer>& peer,
    const std::deque<size_t>& excludedIndexes) = 0;
 
+#endif // ENABLE_BITTORRENT
+
   /**
    * Returns a missing piece if available. Otherwise returns 0;
    */
@@ -142,11 +148,9 @@ public:
   virtual uint64_t getCompletedLength() = 0;
 
   virtual uint64_t getFilteredCompletedLength() = 0;
+
+  virtual void setupFileFilter() = 0;
   
-  virtual void setFileFilter(const std::deque<std::string>& filePaths) = 0;
-
-  virtual void setFileFilter(IntSequence seq) = 0;
-
   virtual void clearFileFilter() = 0;
   
   /**
@@ -177,8 +181,6 @@ public:
 
   virtual bool isSelectiveDownloadingMode() = 0;
 
-  virtual void finishSelectiveDownloadingMode() = 0;
-
   virtual bool isEndGame() = 0;
 
   virtual SharedHandle<DiskAdaptor> getDiskAdaptor() = 0;
