@@ -36,8 +36,13 @@
 #define _D_SEGMENT_MAN_H_
 
 #include "common.h"
-#include "SharedHandle.h"
+
 #include <deque>
+#include <map>
+
+#include "SharedHandle.h"
+#include "TimeA2.h"
+#include "Command.h"
 
 namespace aria2 {
 
@@ -51,10 +56,10 @@ class Piece;
 
 class SegmentEntry {
 public:
-  int32_t cuid;
+  cuid_t cuid;
   SharedHandle<Segment> segment;
 public:
-  SegmentEntry(int32_t cuid, const SharedHandle<Segment>& segment);
+  SegmentEntry(cuid_t cuid, const SharedHandle<Segment>& segment);
 
   ~SegmentEntry();
 };
@@ -79,7 +84,14 @@ private:
 
   std::deque<SharedHandle<PeerStat> > peerStats;
 
-  SharedHandle<Segment> checkoutSegment(int32_t cuid,
+  // key: PeerStat's cuid, value: its download speed
+  std::map<cuid_t, unsigned int> _peerStatDlspdMap;
+
+  Time _lastPeerStatDlspdMapUpdated;
+
+  unsigned int _cachedDlspd;
+
+  SharedHandle<Segment> checkoutSegment(cuid_t cuid,
 					const SharedHandle<Piece>& piece);
 
   SharedHandle<SegmentEntry> findSlowerSegmentEntry
@@ -115,9 +127,9 @@ public:
    * This function doesn't clear passed segments.
    */
   void getInFlightSegment(std::deque<SharedHandle<Segment> >& segments,
-			  int32_t cuid);
+			  cuid_t cuid);
 
-  SharedHandle<Segment> getSegment(int32_t cuid);
+  SharedHandle<Segment> getSegment(cuid_t cuid);
 
   /**
    * Returns a segment whose index is index. 
@@ -125,7 +137,7 @@ public:
    * to another cuid or has been downloaded, then returns a segment instance
    * whose isNull call is true.
    */
-  SharedHandle<Segment> getSegment(int32_t cuid, size_t index);
+  SharedHandle<Segment> getSegment(cuid_t cuid, size_t index);
   /**
    * Updates download status.
    */
@@ -134,11 +146,11 @@ public:
    * Cancels all the segment which the command having given cuid
    * uses.
    */
-  void cancelSegment(int32_t cuid);
+  void cancelSegment(cuid_t cuid);
   /**
    * Tells SegmentMan that the segment has been downloaded successfully.
    */
-  bool completeSegment(int32_t cuid, const SharedHandle<Segment>& segment);
+  bool completeSegment(cuid_t cuid, const SharedHandle<Segment>& segment);
 
   /**
    * Injects PieceStorage.
@@ -169,15 +181,19 @@ public:
    * Returns peerStat whose cuid is given cuid. If it is not found, returns
    * 0.
    */
-  SharedHandle<PeerStat> getPeerStat(int32_t cuid) const;
+  SharedHandle<PeerStat> getPeerStat(cuid_t cuid) const;
 
-
-  const std::deque<SharedHandle<PeerStat> >& getPeerStats() const;
+  const std::deque<SharedHandle<PeerStat> >& getPeerStats() const
+  {
+    return peerStats;
+  }
 
   /**
    * Returns current download speed in bytes per sec. 
    */
-  unsigned int calculateDownloadSpeed() const;
+  unsigned int calculateDownloadSpeed();
+
+  void updateDownloadSpeedFor(const SharedHandle<PeerStat>& pstat);
 
   /**
    * Returns the downloaded bytes in this session.
