@@ -39,23 +39,19 @@
 #include "BtContext.h"
 #include "PeerStorage.h"
 #include "PieceStorage.h"
-#include "BtRuntime.h"
-#include "BtRegistry.h"
+
+namespace aria2 {
 
 class ShareRatioSeedCriteria : public SeedCriteria {
 private:
   double ratio;
-  BtContextHandle btContext;
-  PeerStorageHandle peerStorage;
-  PieceStorageHandle pieceStorage;
-  BtRuntimeHandle btRuntime;
+  SharedHandle<BtContext> btContext;
+  SharedHandle<PeerStorage> _peerStorage;
+  SharedHandle<PieceStorage> _pieceStorage;
 public:
-  ShareRatioSeedCriteria(double ratio, const BtContextHandle& btContext)
+  ShareRatioSeedCriteria(double ratio, const SharedHandle<BtContext>& btContext)
     :ratio(ratio),
-     btContext(btContext),
-     peerStorage(PEER_STORAGE(btContext)),
-     pieceStorage(PIECE_STORAGE(btContext)),
-     btRuntime(BT_RUNTIME(btContext)) {}
+     btContext(btContext) {}
 
   virtual ~ShareRatioSeedCriteria() {}
 
@@ -65,11 +61,10 @@ public:
     if(btContext->getTotalLength() == 0) {
       return false;
     }
-    TransferStat stat = peerStorage->calculateStat();
-    int64_t allTimeUploadLength =
-      btRuntime->getUploadLengthAtStartup()+stat.getSessionUploadLength();
+    TransferStat stat = _peerStorage->calculateStat();
     return ratio <=
-      ((double)allTimeUploadLength)/pieceStorage->getCompletedLength();
+      (double)stat.getAllTimeUploadLength()/
+       _pieceStorage->getCompletedLength();
   }
 
   void setRatio(double ratio) {
@@ -79,6 +74,18 @@ public:
   double getRatio() const {
     return ratio;
   }
+
+  void setPeerStorage(const SharedHandle<PeerStorage>& peerStorage)
+  {
+    _peerStorage = peerStorage;
+  }
+
+  void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage)
+  {
+    _pieceStorage = pieceStorage;
+  }
 };
 
+} // namespace aria2
+
 #endif // _D_SHARE_RATIO_SEED_CRITERIA_H_
