@@ -43,11 +43,14 @@
 #include <utility>
 #include <deque>
 #include <iosfwd>
+#include <numeric>
+#include <map>
 
 #include "SharedHandle.h"
 #include "IntSequence.h"
 #include "a2time.h"
 #include "a2netcompat.h"
+#include "a2functional.h"
 
 namespace aria2 {
 
@@ -209,8 +212,6 @@ public:
   // this function temporarily put here
   static std::string getContentDispositionFilename(const std::string& header);
 
-  static unsigned int countBit(uint32_t n);
-  
   static std::string randomAlpha(size_t length,
 				 const SharedHandle<Randomizer>& randomizer);
   
@@ -277,6 +278,36 @@ public:
 
   static std::pair<std::string, uint16_t>
   getNumericNameInfo(const struct sockaddr* sockaddr, socklen_t len);
+
+  static std::string htmlEscape(const std::string& src);
+
+  // Joins path element specified in [first, last).  If ".." is found,
+  // it eats the previous element if it exists.  If "." is found, it
+  // is just ignored and it is not appeared in the result.
+  template<typename InputIterator>
+  static std::string joinPath(InputIterator first, InputIterator last)
+  {
+    std::deque<std::string> elements;
+    for(;first != last; ++first) {
+      if(*first == "..") {
+	if(!elements.empty()) {
+	  elements.pop_back();
+	}
+      } else if(*first == ".") {
+	// do nothing
+      } else {
+	elements.push_back(*first);
+      }
+    }
+    return strjoin(elements.begin(), elements.end(), "/");
+  }
+
+  // Parses INDEX=PATH format string. INDEX must be an unsigned
+  // integer.
+  static std::map<size_t, std::string>::value_type
+  parseIndexPath(const std::string& line);
+
+  static std::map<size_t, std::string> createIndexPathMap(std::istream& i);
 };
 
 } // namespace aria2
