@@ -1,8 +1,11 @@
 #include "BtHaveMessage.h"
 #include "PeerMessageUtil.h"
+#include "Peer.h"
+#include "MockPieceStorage.h"
+#include <cstring>
 #include <cppunit/extensions/HelperMacros.h>
 
-using namespace std;
+namespace aria2 {
 
 class BtHaveMessageTest:public CppUnit::TestFixture {
 
@@ -31,9 +34,9 @@ void BtHaveMessageTest::testCreate() {
   unsigned char msg[9];
   PeerMessageUtil::createPeerMessageString(msg, sizeof(msg), 5, 4);
   PeerMessageUtil::setIntParam(&msg[5], 12345);
-  BtHaveMessageHandle pm = BtHaveMessage::create(&msg[4], 5);
-  CPPUNIT_ASSERT_EQUAL((int8_t)4, pm->getId());
-  CPPUNIT_ASSERT_EQUAL((int32_t)12345, pm->getIndex());
+  SharedHandle<BtHaveMessage> pm = BtHaveMessage::create(&msg[4], 5);
+  CPPUNIT_ASSERT_EQUAL((uint8_t)4, pm->getId());
+  CPPUNIT_ASSERT_EQUAL((size_t)12345, pm->getIndex());
 
   // case: payload size is wrong
   try {
@@ -63,10 +66,13 @@ void BtHaveMessageTest::testGetMessage() {
 }
 
 void BtHaveMessageTest::testDoReceivedAction() {
-  PeerHandle peer = new Peer("host", 6969, 16*1024, 256*1024);
+  SharedHandle<Peer> peer(new Peer("host", 6969));
+  peer->allocateSessionResource(16*1024, 256*1024);
   BtHaveMessage msg;
   msg.setIndex(1);
   msg.setPeer(peer);
+  SharedHandle<MockPieceStorage> pieceStorage(new MockPieceStorage());
+  msg.setPieceStorage(pieceStorage);
 
   CPPUNIT_ASSERT(!peer->hasPiece(msg.getIndex()));
 
@@ -79,5 +85,7 @@ void BtHaveMessageTest::testToString() {
   BtHaveMessage msg;
   msg.setIndex(1);
 
-  CPPUNIT_ASSERT_EQUAL(string("have index=1"), msg.toString());
+  CPPUNIT_ASSERT_EQUAL(std::string("have index=1"), msg.toString());
 }
+
+} // namespace aria2
