@@ -1,11 +1,16 @@
 #include "BtRejectMessage.h"
-#include "PeerMessageUtil.h"
-#include "Peer.h"
-#include "MockBtMessageDispatcher.h"
-#include "MockBtContext.h"
+
+#include <cstring>
+
 #include <cppunit/extensions/HelperMacros.h>
 
-using namespace std;
+#include "PeerMessageUtil.h"
+#include "Peer.h"
+#include "FileEntry.h"
+#include "MockBtMessageDispatcher.h"
+#include "MockBtContext.h"
+
+namespace aria2 {
 
 class BtRejectMessageTest:public CppUnit::TestFixture {
 
@@ -37,8 +42,8 @@ public:
       this->slot = slot;
     }
 
-    virtual RequestSlot getOutstandingRequest(int32_t index, int32_t begin,
-					      int32_t length) {
+    virtual RequestSlot getOutstandingRequest(size_t index, uint32_t begin,
+					      size_t length) {
       if(slot.getIndex() == index && slot.getBegin() == begin &&
 	 slot.getLength() == length) {
 	return slot;
@@ -58,32 +63,27 @@ public:
 
   typedef SharedHandle<MockBtMessageDispatcher2> MockBtMessageDispatcher2Handle;
 
-  PeerHandle peer;
-  MockBtMessageDispatcher2Handle dispatcher;
-  BtRejectMessageHandle msg;
-
-  BtRejectMessageTest():peer(0), dispatcher(0), msg(0) {}
+  SharedHandle<MockBtContext> _btContext;
+  SharedHandle<Peer> peer;
+  SharedHandle<MockBtMessageDispatcher2> dispatcher;
+  SharedHandle<BtRejectMessage> msg;
 
   void setUp() {
-    BtRegistry::unregisterAll();
-    peer = new Peer("host", 6969, 16*1024, 256*1024);
+    peer.reset(new Peer("host", 6969));
+    peer->allocateSessionResource(1024, 1024*1024);
 
-    MockBtContextHandle btContext = new MockBtContext();
-    btContext->setInfoHash((const unsigned char*)"12345678901234567890");
-    BtRegistry::registerPeerObjectCluster(btContext->getInfoHashAsString(),
-					  new PeerObjectCluster());
-    PEER_OBJECT_CLUSTER(btContext)->registerHandle(peer->getId(), new PeerObject());
-    dispatcher = new MockBtMessageDispatcher2();
-    PEER_OBJECT(btContext, peer)->btMessageDispatcher = dispatcher;
+    _btContext.reset(new MockBtContext());
+    _btContext->setInfoHash((const unsigned char*)"12345678901234567890");
 
-    msg = new BtRejectMessage();
+    dispatcher.reset(new MockBtMessageDispatcher2());
+
+    msg.reset(new BtRejectMessage());
     msg->setPeer(peer);
-    msg->setBtContext(btContext);
+    msg->setBtContext(_btContext);
     msg->setIndex(1);
     msg->setBegin(16);
     msg->setLength(32);
     msg->setBtMessageDispatcher(dispatcher);
-
   }
 };
 
@@ -96,11 +96,11 @@ void BtRejectMessageTest::testCreate() {
   PeerMessageUtil::setIntParam(&msg[5], 12345);
   PeerMessageUtil::setIntParam(&msg[9], 256);
   PeerMessageUtil::setIntParam(&msg[13], 1024);
-  BtRejectMessageHandle pm = BtRejectMessage::create(&msg[4], 13);
-  CPPUNIT_ASSERT_EQUAL((int8_t)16, pm->getId());
-  CPPUNIT_ASSERT_EQUAL((int32_t)12345, pm->getIndex());
-  CPPUNIT_ASSERT_EQUAL((int32_t)256, pm->getBegin());
-  CPPUNIT_ASSERT_EQUAL((int32_t)1024, pm->getLength());
+  SharedHandle<BtRejectMessage> pm = BtRejectMessage::create(&msg[4], 13);
+  CPPUNIT_ASSERT_EQUAL((uint8_t)16, pm->getId());
+  CPPUNIT_ASSERT_EQUAL((size_t)12345, pm->getIndex());
+  CPPUNIT_ASSERT_EQUAL((uint32_t)256, pm->getBegin());
+  CPPUNIT_ASSERT_EQUAL((size_t)1024, pm->getLength());
 
   // case: payload size is wrong
   try {
@@ -138,11 +138,13 @@ void BtRejectMessageTest::testDoReceivedAction() {
   RequestSlot slot(1, 16, 32, 2);
   dispatcher->setRequestSlot(slot);
   
-  CPPUNIT_ASSERT(!RequestSlot::isNull(dispatcher->getOutstandingRequest(1, 16, 32)));
+  CPPUNIT_ASSERT
+    (!RequestSlot::isNull(dispatcher->getOutstandingRequest(1, 16, 32)));
 
   msg->doReceivedAction();
 
-  CPPUNIT_ASSERT(RequestSlot::isNull(dispatcher->getOutstandingRequest(1, 16, 32)));
+  CPPUNIT_ASSERT
+    (RequestSlot::isNull(dispatcher->getOutstandingRequest(1, 16, 32)));
 }
 
 void BtRejectMessageTest::testDoReceivedActionNoMatch() {
@@ -150,11 +152,13 @@ void BtRejectMessageTest::testDoReceivedActionNoMatch() {
   RequestSlot slot(2, 16, 32, 2);
   dispatcher->setRequestSlot(slot);
   
-  CPPUNIT_ASSERT(!RequestSlot::isNull(dispatcher->getOutstandingRequest(2, 16, 32)));
+  CPPUNIT_ASSERT
+    (!RequestSlot::isNull(dispatcher->getOutstandingRequest(2, 16, 32)));
 
   msg->doReceivedAction();
 
-  CPPUNIT_ASSERT(!RequestSlot::isNull(dispatcher->getOutstandingRequest(2, 16, 32)));  
+  CPPUNIT_ASSERT
+    (!RequestSlot::isNull(dispatcher->getOutstandingRequest(2, 16, 32)));  
 
 }
 
@@ -162,7 +166,8 @@ void BtRejectMessageTest::testDoReceivedActionFastExtensionDisabled() {
   RequestSlot slot(1, 16, 32, 2);
   dispatcher->setRequestSlot(slot);
   
-  CPPUNIT_ASSERT(!RequestSlot::isNull(dispatcher->getOutstandingRequest(1, 16, 32)));
+  CPPUNIT_ASSERT
+    (!RequestSlot::isNull(dispatcher->getOutstandingRequest(1, 16, 32)));
   try {
     msg->doReceivedAction();
     CPPUNIT_FAIL("exception must be thrown.");
@@ -171,6 +176,8 @@ void BtRejectMessageTest::testDoReceivedActionFastExtensionDisabled() {
 }
 
 void BtRejectMessageTest::testToString() {
-  CPPUNIT_ASSERT_EQUAL(string("reject index=1, begin=16, length=32"),
+  CPPUNIT_ASSERT_EQUAL(std::string("reject index=1, begin=16, length=32"),
 		       msg->toString());
 }
+
+} // namespace aria2
