@@ -1,16 +1,21 @@
 #include "IteratableChunkChecksumValidator.h"
+
+#include <cppunit/extensions/HelperMacros.h>
+
 #include "SingleFileDownloadContext.h"
 #include "DefaultPieceStorage.h"
 #include "Option.h"
 #include "DiskAdaptor.h"
-#include <cppunit/extensions/HelperMacros.h>
+#include "FileEntry.h"
+#include "PieceSelector.h"
 
-using namespace std;
+namespace aria2 {
 
 class IteratableChunkChecksumValidatorTest:public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(IteratableChunkChecksumValidatorTest);
   CPPUNIT_TEST(testValidate);
+  CPPUNIT_TEST(testValidate_readError);
   CPPUNIT_TEST_SUITE_END();
 private:
 
@@ -20,6 +25,7 @@ public:
   }
 
   void testValidate();
+  void testValidate_readError();
 };
 
 
@@ -31,11 +37,12 @@ const char* IteratableChunkChecksumValidatorTest::csArray[] = { "29b0e7878271645
 
 void IteratableChunkChecksumValidatorTest::testValidate() {
   Option option;
-  SingleFileDownloadContextHandle dctx =
-    new SingleFileDownloadContext(100, 250, "chunkChecksumTestFile250.txt");
-  dctx->setPieceHashes(Strings(&csArray[0], &csArray[3]));
+  SharedHandle<SingleFileDownloadContext> dctx
+    (new SingleFileDownloadContext(100, 250, "chunkChecksumTestFile250.txt"));
+  dctx->setPieceHashes(std::deque<std::string>(&csArray[0], &csArray[3]));
   dctx->setPieceHashAlgo("sha1");
-  DefaultPieceStorageHandle ps = new DefaultPieceStorage(dctx, &option);
+  SharedHandle<DefaultPieceStorage> ps
+    (new DefaultPieceStorage(dctx, &option));
   ps->initStorage();
   ps->getDiskAdaptor()->openFile();
 
@@ -51,7 +58,7 @@ void IteratableChunkChecksumValidatorTest::testValidate() {
   CPPUNIT_ASSERT(ps->downloadFinished());
 
   // make the test fail
-  Strings badHashes(&csArray[0], &csArray[3]);
+  std::deque<std::string> badHashes(&csArray[0], &csArray[3]);
   badHashes[1] = "ffffffffffffffffffffffffffffffffffffffff";
   dctx->setPieceHashes(badHashes);
 
@@ -64,3 +71,35 @@ void IteratableChunkChecksumValidatorTest::testValidate() {
   CPPUNIT_ASSERT(!ps->hasPiece(1));
   CPPUNIT_ASSERT(ps->hasPiece(2));
 }
+
+void IteratableChunkChecksumValidatorTest::testValidate_readError() {
+  Option option;
+  SharedHandle<SingleFileDownloadContext> dctx
+    (new SingleFileDownloadContext(100, 500, "chunkChecksumTestFile250.txt"));
+  std::deque<std::string> hashes(&csArray[0], &csArray[3]);
+  hashes.push_back("ffffffffffffffffffffffffffffffffffffffff");
+  hashes.push_back("ffffffffffffffffffffffffffffffffffffffff");
+  dctx->setPieceHashes(hashes);
+  dctx->setPieceHashAlgo("sha1");
+  SharedHandle<DefaultPieceStorage> ps(new DefaultPieceStorage(dctx, &option));
+  ps->initStorage();
+  ps->getDiskAdaptor()->openFile();
+
+  IteratableChunkChecksumValidator validator(dctx, ps);
+  validator.init();
+
+  while(!validator.finished()) {
+    validator.validateChunk();
+  }
+
+  CPPUNIT_ASSERT(ps->hasPiece(0));
+  CPPUNIT_ASSERT(ps->hasPiece(1));
+  CPPUNIT_ASSERT(!ps->hasPiece(2)); // #2 piece is not valid because
+				    // #program expects its size is
+				    // #100, but it reads only 50
+				    // #bytes and raises error.
+  CPPUNIT_ASSERT(!ps->hasPiece(3));
+  CPPUNIT_ASSERT(!ps->hasPiece(4));
+}
+
+} // namespace aria2
