@@ -89,7 +89,9 @@ public:
     fileEntries.push_back(fileEntry);
   }
 
-  virtual std::deque<SharedHandle<AnnounceTier> > getAnnounceTiers() const {
+  virtual const std::deque<SharedHandle<AnnounceTier> >&
+  getAnnounceTiers() const
+  {
     return announceTiers;
   }
 
@@ -168,6 +170,7 @@ public:
     _nodes = nodes;
   }
 
+  virtual void setFileFilter(IntSequence seq) {}
 };
 
 } // namespace aria2
