@@ -1,8 +1,10 @@
 #include "TimeSeedCriteria.h"
-#include "Util.h"
 
 #include <cppunit/extensions/HelperMacros.h>
-#include <stdlib.h>
+
+#include "Util.h"
+
+namespace aria2 {
 
 class TimeSeedCriteriaTest:public CppUnit::TestFixture {
 
@@ -19,9 +21,12 @@ CPPUNIT_TEST_SUITE_REGISTRATION(TimeSeedCriteriaTest);
 
 void TimeSeedCriteriaTest::testEvaluate() {
   TimeSeedCriteria cri(1);
-  Util::sleep(1);
+  // Seel 2seconds. 1 seconds are not enough in some systems.
+  Util::sleep(2);
   CPPUNIT_ASSERT(cri.evaluate());
   cri.reset();
   cri.setDuration(10);
   CPPUNIT_ASSERT(!cri.evaluate());
 }
+
+} // namespace aria2
